@@ -3,8 +3,8 @@
  * Copyright (C) 1997-2019 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -16,6 +16,7 @@
 #include "inputint.h"
 #include "inputstring.h"
 #include "inputstrlist.h"
+#include "inputobsolete.h"
 #include "config.h"
 #include "version.h"
 #include "configdoc.h"
@@ -32,15 +33,15 @@
 #include <QMessageBox>
 #include <QSettings>
 #include <QTextStream>
-#include <QTextCodec>
 #include <QFileInfo>
+#include <QRegularExpression>
 
 #define SA(x) QString::fromLatin1(x)
 
 
 static QString convertToComment(const QString &s)
 {
-  if (s.isEmpty()) 
+  if (s.isEmpty())
   {
     return QString();
   }
@@ -122,7 +123,7 @@ Expert::Expert()
 Expert::~Expert()
 {
   QHashIterator<QString,Input*> i(m_options);
-  while (i.hasNext()) 
+  while (i.hasNext())
   {
     i.next();
     delete i.value();
@@ -388,7 +389,7 @@ static QString getDocsForNode(const QDomElement &child)
       }
     }
   }
-  
+
   if (child.hasAttribute(SA("depends")))
   {
     QString dependsOn = child.attribute(SA("depends"));
@@ -403,7 +404,7 @@ static QString getDocsForNode(const QDomElement &child)
   // Remove / replace doxygen markup strings
   // the regular expressions are hard to read so the intention will be given
   // Note: see also configgen.py in the src directory for other doxygen parts
-  QRegExp regexp;
+  QRegularExpression regexp;
   // remove \n at end and replace by a space
   regexp.setPattern(SA("\\n$"));
   docs.replace(regexp,SA(" "));
@@ -509,7 +510,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
       QString docs = getDocsForNode(child);
       if (type==SA("bool"))
       {
-        InputBool *boolOption = 
+        InputBool *boolOption =
           new InputBool(
               layout,row,
               child.attribute(SA("id")),
@@ -535,6 +536,10 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
         {
           mode = InputString::StringFile;
         }
+        else if (format==SA("filedir"))
+        {
+          mode = InputString::StringFileDir;
+        }
         else if (format==SA("image"))
         {
           mode = InputString::StringImage;
@@ -543,7 +548,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
         {
           mode = InputString::StringFree;
         }
-        InputString *stringOption = 
+        InputString *stringOption =
           new InputString(
               layout,row,
               child.attribute(SA("id")),
@@ -585,7 +590,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
       }
       else if (type==SA("int"))
       {
-        InputInt *intOption = 
+        InputInt *intOption =
           new InputInt(
               layout,row,
               child.attribute(SA("id")),
@@ -631,7 +636,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
           }
           listVal = listVal.nextSiblingElement();
         }
-        InputStrList *listOption = 
+        InputStrList *listOption =
           new InputStrList(
               layout,row,
               child.attribute(SA("id")),
@@ -648,6 +653,31 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
       }
       else if (type==SA("obsolete"))
       {
+        Input::Kind orgKind;
+        QString orgKindStr = child.attribute(SA("orgtype"));
+        if (orgKindStr==SA("int"))
+        {
+          orgKind = Input::Int;
+        }
+        else if (orgKindStr==SA("bool"))
+        {
+          orgKind = Input::Bool;
+        }
+        else if (orgKindStr==SA("string") || orgKindStr==SA("enum"))
+        {
+          orgKind = Input::String;
+        }
+        else if (orgKindStr==SA("strlist"))
+        {
+          orgKind = Input::StrList;
+        }
+        else
+        {
+          orgKind = Input::Obsolete;
+        }
+        InputObsolete *obsoleteOption =
+          new InputObsolete(child.attribute(SA("id")),orgKind);
+        m_options.insert(child.attribute(SA("id")),obsoleteOption);
         // ignore
       }
       else // should not happen
@@ -665,7 +695,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
     QString setting = child.attribute(SA("setting"));
     QString dependsOn = child.attribute(SA("depends"));
     QString id        = child.attribute(SA("id"));
-    if (!dependsOn.isEmpty() && 
+    if (!dependsOn.isEmpty() &&
         (setting.isEmpty() || IS_SUPPORTED(setting.toLatin1())))
     {
        Input *parentOption = m_options[dependsOn];
@@ -690,7 +720,7 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
 
   // set initial dependencies
   QHashIterator<QString,Input*> i(m_options);
-  while (i.hasNext()) 
+  while (i.hasNext())
   {
     i.next();
     if (i.value())
@@ -714,7 +744,7 @@ void Expert::activateTopic(QTreeWidgetItem *item,QTreeWidgetItem *)
   {
     QWidget *w = m_topics[item->text(0)];
     m_topicStack->setCurrentWidget(w);
-    m_prev->setEnabled(m_topicStack->currentIndex()!=0); 
+    m_prev->setEnabled(m_topicStack->currentIndex()!=0);
     m_next->setEnabled(true);
   }
 }
@@ -722,11 +752,11 @@ void Expert::activateTopic(QTreeWidgetItem *item,QTreeWidgetItem *)
 void Expert::loadSettings(QSettings *s)
 {
   QHashIterator<QString,Input*> i(m_options);
-  while (i.hasNext()) 
+  while (i.hasNext())
   {
     i.next();
     QVariant var = s->value(SA("config/")+i.key());
-    if (i.value())
+    if (i.value() && var.isValid())
     {
       //printf("Loading key %s: type=%d value='%s'\n",qPrintable(i.key()),var.type(),qPrintable(var.toString()));
       i.value()->value() = var;
@@ -738,7 +768,7 @@ void Expert::loadSettings(QSettings *s)
 void Expert::saveSettings(QSettings *s)
 {
   QHashIterator<QString,Input*> i(m_options);
-  while (i.hasNext()) 
+  while (i.hasNext())
   {
     i.next();
     //printf("Saving key %s: type=%d value='%s'\n",qPrintable(i.key()),i.value()->value().type(),qPrintable(i.value()->value().toString()));
@@ -755,18 +785,18 @@ void Expert::loadConfig(const QString &fileName)
   parseConfig(fileName,m_options);
 }
 
-void Expert::saveTopic(QTextStream &t,QDomElement &elem,QTextCodec *codec,
+void Expert::saveTopic(QTextStream &t,QDomElement &elem,TextCodecAdapter *codec,
                        bool brief,bool condensed)
 {
   if (!brief)
   {
-    t << endl;
+    t << "\n";
   }
   if (!condensed)
   {
-    t << "#---------------------------------------------------------------------------" << endl;
-    t << "# " << elem.attribute(SA("docs")) << endl;
-    t << "#---------------------------------------------------------------------------" << endl;
+    t << "#---------------------------------------------------------------------------\n";
+    t << "# " << elem.attribute(SA("docs")) << "\n";
+    t << "#---------------------------------------------------------------------------\n";
   }
   // write options...
   QDomElement childElem = elem.firstChildElement();
@@ -781,23 +811,26 @@ void Expert::saveTopic(QTextStream &t,QDomElement &elem,QTextCodec *codec,
       if (i!=m_options.end())
       {
         Input *option = i.value();
-        if (option && !brief)
+        if (option->kind()!=Input::Obsolete)
         {
-          t << endl;
-          t << convertToComment(option->templateDocs());
-          t << endl;
-        }
-        bool toPrint = true;
-        if (option && condensed) toPrint = !option->isDefault();
-        if (toPrint)
-        {
-          t << name.leftJustified(MAX_OPTION_LENGTH) << "=";
-          if (option && !option->isEmpty())
+          if (option && !brief)
           {
-            t << " ";
-            option->writeValue(t,codec);
+            t << "\n";
+            t << convertToComment(option->templateDocs());
+            t << "\n";
+          }
+          bool toPrint = true;
+          if (option && condensed) toPrint = !option->isDefault();
+          if (toPrint)
+          {
+            t << name.leftJustified(MAX_OPTION_LENGTH) << "=";
+            if (option && !option->isEmpty())
+            {
+              t << " ";
+              option->writeValue(t,codec);
+            }
+            t << "\n";
           }
-          t << endl;
         }
       }
     }
@@ -808,28 +841,20 @@ void Expert::saveTopic(QTextStream &t,QDomElement &elem,QTextCodec *codec,
 bool Expert::writeConfig(QTextStream &t,bool brief, bool condensed)
 {
   // write global header
-  t << "# Doxyfile " << getDoxygenVersion() << endl << endl;
+  t << "# Doxyfile " << getDoxygenVersion() << "\n\n";
   if (!brief && !condensed)
   {
     t << convertToComment(m_header);
   }
 
-  QTextCodec *codec = 0;
   Input *option = m_options[QString::fromLatin1("DOXYFILE_ENCODING")];
-  if (option)
-  {
-    codec = QTextCodec::codecForName(option->value().toString().toLatin1());
-    if (codec==0) // fallback: use UTF-8
-    {
-      codec = QTextCodec::codecForName("UTF-8");
-    }
-  }
+  TextCodecAdapter codec(option->value().toString().toLatin1());
   QDomElement childElem = m_rootElement.firstChildElement();
   while (!childElem.isNull())
   {
     if (childElem.tagName()==SA("group"))
     {
-      saveTopic(t,childElem,codec,brief,condensed);
+      saveTopic(t,childElem,&codec,brief,condensed);
     }
     childElem = childElem.nextSiblingElement();
   }
@@ -890,7 +915,7 @@ void Expert::resetToDefaults()
 {
   //printf("Expert::makeDefaults()\n");
   QHashIterator<QString,Input*> i(m_options);
-  while (i.hasNext()) 
+  while (i.hasNext())
   {
     i.next();
     if (i.value())
@@ -904,7 +929,7 @@ static bool stringVariantToBool(const QVariant &v)
 {
   QString s = v.toString().toLower();
   return s==QString::fromLatin1("yes") || s==QString::fromLatin1("true") || s==QString::fromLatin1("1");
-} 
+}
 
 static bool getBoolOption(
     const QHash<QString,Input*>&model,const QString &name)
@@ -912,7 +937,7 @@ static bool getBoolOption(
   Input *option = model[name];
   Q_ASSERT(option!=0);
   return stringVariantToBool(option->value());
-} 
+}
 
 static QString getStringOption(
     const QHash<QString,Input*>&model,const QString &name)
@@ -944,7 +969,7 @@ QString Expert::getHtmlOutputIndex(const QString &workingDir) const
     indexFile = outputDir;
   }
   else // append
-  { 
+  {
     indexFile += QString::fromLatin1("/")+outputDir;
   }
   if (QFileInfo(htmlOutputDir).isAbsolute()) // override
