@@ -1,13 +1,13 @@
 /******************************************************************************
  *
- * 
+ *
  *
  *
  * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -19,12 +19,16 @@
 #ifndef CONFIGIMPL_H
 #define CONFIGIMPL_H
 
-#include <qstrlist.h>
-#include <qdict.h>
-#include <qlist.h>
-#include <qregexp.h>
-#include "ftextstream.h"
+#include <vector>
+#include <unordered_map>
+#include <string>
+#include <memory>
+#include <iostream>
 
+#include "containers.h"
+#include "qcstring.h"
+
+class TextStream;
 
 /** Abstract base class for any configuration option.
  */
@@ -35,25 +39,25 @@ class ConfigOption
   public:
 
     /*! The type of option */
-    enum OptionType 
-    { 
-      O_Info,      //<! A section header
-      O_List,      //<! A list of items
-      O_Enum,      //<! A fixed set of items
-      O_String,    //<! A single item
-      O_Int,       //<! An integer value
-      O_Bool,      //<! A boolean value
-      O_Obsolete,  //<! An obsolete option
-      O_Disabled   //<! Disabled compile time option
+    enum OptionType
+    {
+      O_Info,      //!< A section header
+      O_List,      //!< A list of items
+      O_Enum,      //!< A fixed set of items
+      O_String,    //!< A single item
+      O_Int,       //!< An integer value
+      O_Bool,      //!< A boolean value
+      O_Obsolete,  //!< An obsolete option
+      O_Disabled   //!< Disabled compile time option
     };
-    enum 
-    { 
-     /*! Maximum length of an option in the config file. Used for 
+    enum
+    {
+     /*! Maximum length of an option in the config file. Used for
       *  alignment purposes.
       */
-      MAX_OPTION_LENGTH = 23  
+      MAX_OPTION_LENGTH = 23
     };
-    ConfigOption(OptionType t) : m_kind(t) 
+    ConfigOption(OptionType t) : m_kind(t)
     {
       m_spaces.fill(' ',40);
     }
@@ -72,17 +76,19 @@ class ConfigOption
     void setUserComment(const QCString &u) { m_userComment += u; }
 
   protected:
-    virtual void writeTemplate(FTextStream &t,bool sl,bool upd) = 0;
-    virtual void compareDoxyfile(FTextStream &t) = 0;
+    virtual void writeTemplate(TextStream &t,bool sl,bool upd) = 0;
+    virtual void compareDoxyfile(TextStream &t) = 0;
+    virtual void writeXMLDoxyfile(TextStream &t) = 0;
     virtual void convertStrToVal() {}
     virtual void emptyValueToDefault() {}
     virtual void substEnvVars() = 0;
     virtual void init() {}
+    virtual bool isDefault() { return true; }
 
-    void writeBoolValue(FTextStream &t,bool v);
-    void writeIntValue(FTextStream &t,int i);
-    void writeStringValue(FTextStream &t,QCString &s);
-    void writeStringList(FTextStream &t,QStrList &l);
+    void writeBoolValue(TextStream &t,bool v,bool initSpace = true);
+    void writeIntValue(TextStream &t,int i,bool initSpace = true);
+    void writeStringValue(TextStream &t,const QCString &s,bool initSpace = true);
+    void writeStringList(TextStream &t,const StringVector &l);
 
     QCString m_spaces;
     QCString m_name;
@@ -98,41 +104,46 @@ class ConfigOption
 class ConfigInfo : public ConfigOption
 {
   public:
-    ConfigInfo(const char *name,const char *doc) 
+    ConfigInfo(const char *name,const char *doc)
       : ConfigOption(O_Info)
     {
       m_name = name;
       m_doc = doc;
     }
-    void writeTemplate(FTextStream &t, bool sl,bool);
-    void compareDoxyfile(FTextStream &){};
+    void writeTemplate(TextStream &t, bool sl,bool);
+    void compareDoxyfile(TextStream &) {}
+    void writeXMLDoxyfile(TextStream &) {}
     void substEnvVars() {}
 };
 
-/** Class respresenting a list type option.
+/** Class representing a list type option.
  */
 class ConfigList : public ConfigOption
 {
   public:
     enum WidgetType { String, File, Dir, FileAndDir };
-    ConfigList(const char *name,const char *doc) 
+    ConfigList(const char *name,const char *doc)
       : ConfigOption(O_List)
     {
       m_name = name;
       m_doc = doc;
       m_widgetType = String;
     }
-    void addValue(const char *v) { m_defaultValue.append(v); }
+    void addValue(const char *v) { m_defaultValue.push_back(v); }
     void setWidgetType(WidgetType w) { m_widgetType = w; }
     WidgetType widgetType() const { return m_widgetType; }
-    QStrList *valueRef() { return &m_value; }
-    void writeTemplate(FTextStream &t,bool sl,bool);
-    void compareDoxyfile(FTextStream &t);
+    StringVector *valueRef() { return &m_value; }
+    StringVector getDefault() { return m_defaultValue; }
+    void emptyValueToDefault() { if (m_value.empty() && !m_defaultValue.empty()) m_value=m_defaultValue; };
+    void writeTemplate(TextStream &t,bool sl,bool);
+    void compareDoxyfile(TextStream &t);
+    void writeXMLDoxyfile(TextStream &t);
     void substEnvVars();
     void init() { m_value = m_defaultValue; }
+    bool isDefault();
   private:
-    QStrList m_value;
-    QStrList m_defaultValue;
+    StringVector m_value;
+    StringVector m_defaultValue;
     WidgetType m_widgetType;
 };
 
@@ -141,7 +152,7 @@ class ConfigList : public ConfigOption
 class ConfigEnum : public ConfigOption
 {
   public:
-    ConfigEnum(const char *name,const char *doc,const char *defVal) 
+    ConfigEnum(const char *name,const char *doc,const char *defVal)
       : ConfigOption(O_Enum)
     {
       m_name = name;
@@ -149,19 +160,19 @@ class ConfigEnum : public ConfigOption
       m_value = defVal;
       m_defValue = defVal;
     }
-    void addValue(const char *v) { m_valueRange.append(v); }
-    QStrListIterator iterator() 
-    {
-      return QStrListIterator(m_valueRange);
-    }
+    void addValue(const char *v) { m_valueRange.push_back(v); }
+    const std::vector<QCString> &values() const { return m_valueRange; }
     QCString *valueRef() { return &m_value; }
     void substEnvVars();
-    void writeTemplate(FTextStream &t,bool sl,bool);
-    void compareDoxyfile(FTextStream &t);
-    void init() { m_value = m_defValue.copy(); }
+    void writeTemplate(TextStream &t,bool sl,bool);
+    void convertStrToVal();
+    void compareDoxyfile(TextStream &t);
+    void writeXMLDoxyfile(TextStream &t);
+    void init() { m_value = m_defValue; }
+    bool isDefault() { return m_value == m_defValue; }
 
   private:
-    QStrList m_valueRange;
+    std::vector<QCString> m_valueRange;
     QCString m_value;
     QCString m_defValue;
 };
@@ -171,8 +182,8 @@ class ConfigEnum : public ConfigOption
 class ConfigString : public ConfigOption
 {
   public:
-    enum WidgetType { String, File, Dir, Image };
-    ConfigString(const char *name,const char *doc) 
+    enum WidgetType { String, File, Dir, Image, FileAndDir };
+    ConfigString(const char *name,const char *doc)
       : ConfigOption(O_String)
     {
       m_name = name;
@@ -186,12 +197,14 @@ class ConfigString : public ConfigOption
     WidgetType widgetType() const { return m_widgetType; }
     void setDefaultValue(const char *v) { m_defValue = v; }
     QCString *valueRef() { return &m_value; }
-    void writeTemplate(FTextStream &t,bool sl,bool);
-    void compareDoxyfile(FTextStream &t);
+    void writeTemplate(TextStream &t,bool sl,bool);
+    void compareDoxyfile(TextStream &t);
+    void writeXMLDoxyfile(TextStream &t);
     void substEnvVars();
-    void init() { m_value = m_defValue.copy(); }
-    void emptyValueToDefault() { if(m_value.isEmpty()) m_value=m_defValue; };
-  
+    void init() { m_value = m_defValue; }
+    void emptyValueToDefault() { if (m_value.isEmpty()) m_value=m_defValue; };
+    bool isDefault() { return m_value.stripWhiteSpace() == m_defValue.stripWhiteSpace(); }
+
   private:
     QCString m_value;
     QCString m_defValue;
@@ -203,7 +216,7 @@ class ConfigString : public ConfigOption
 class ConfigInt : public ConfigOption
 {
   public:
-    ConfigInt(const char *name,const char *doc,int minVal,int maxVal,int defVal) 
+    ConfigInt(const char *name,const char *doc,int minVal,int maxVal,int defVal)
       : ConfigOption(O_Int)
     {
       m_name = name;
@@ -219,9 +232,11 @@ class ConfigInt : public ConfigOption
     int maxVal() const { return m_maxVal; }
     void convertStrToVal();
     void substEnvVars();
-    void writeTemplate(FTextStream &t,bool sl,bool upd);
-    void compareDoxyfile(FTextStream &t);
+    void writeTemplate(TextStream &t,bool sl,bool upd);
+    void compareDoxyfile(TextStream &t);
+    void writeXMLDoxyfile(TextStream &t);
     void init() { m_value = m_defValue; }
+    bool isDefault() { return m_value == m_defValue; }
   private:
     int m_value;
     int m_defValue;
@@ -235,7 +250,7 @@ class ConfigInt : public ConfigOption
 class ConfigBool : public ConfigOption
 {
   public:
-    ConfigBool(const char *name,const char *doc,bool defVal) 
+    ConfigBool(const char *name,const char *doc,bool defVal)
       : ConfigOption(O_Bool)
     {
       m_name = name;
@@ -248,9 +263,11 @@ class ConfigBool : public ConfigOption
     void convertStrToVal();
     void substEnvVars();
     void setValueString(const QCString &v) { m_valueString = v; }
-    void writeTemplate(FTextStream &t,bool sl,bool upd);
-    void compareDoxyfile(FTextStream &t);
+    void writeTemplate(TextStream &t,bool sl,bool upd);
+    void compareDoxyfile(TextStream &t);
+    void writeXMLDoxyfile(TextStream &t);
     void init() { m_value = m_defValue; }
+    bool isDefault() { return m_value == m_defValue; }
   private:
     bool m_value;
     bool m_defValue;
@@ -262,11 +279,22 @@ class ConfigBool : public ConfigOption
 class ConfigObsolete : public ConfigOption
 {
   public:
-    ConfigObsolete(const char *name) : ConfigOption(O_Obsolete)  
+    ConfigObsolete(const char *name,OptionType orgType) : ConfigOption(O_Obsolete), m_orgType(orgType)
     { m_name = name; }
-    void writeTemplate(FTextStream &,bool,bool);
-    void compareDoxyfile(FTextStream &) {}
+    void writeTemplate(TextStream &,bool,bool);
+    void compareDoxyfile(TextStream &) {}
+    void writeXMLDoxyfile(TextStream &) {}
     void substEnvVars() {}
+    OptionType orgType() const { return m_orgType; }
+    StringVector *valueListRef() { return &m_listvalue; }
+    QCString *valueStringRef() { return &m_valueString; }
+    void markAsPresent() { m_present = true; }
+    bool isPresent() const { return m_present; }
+  private:
+    OptionType m_orgType;
+    StringVector m_listvalue;
+    QCString m_valueString;
+    bool m_present = false;
 };
 
 /** Section marker for compile time optional options
@@ -274,10 +302,11 @@ class ConfigObsolete : public ConfigOption
 class ConfigDisabled : public ConfigOption
 {
   public:
-    ConfigDisabled(const char *name) : ConfigOption(O_Disabled)  
+    ConfigDisabled(const char *name) : ConfigOption(O_Disabled)
     { m_name = name; }
-    void writeTemplate(FTextStream &,bool,bool);
-    void compareDoxyfile(FTextStream &) {}
+    void writeTemplate(TextStream &,bool,bool);
+    void compareDoxyfile(TextStream &) {}
+    void writeXMLDoxyfile(TextStream &) {}
     void substEnvVars() {}
 };
 
@@ -289,13 +318,16 @@ class ConfigDisabled : public ConfigOption
 #define ConfigImpl_getBool(val)    ConfigImpl::instance()->getBool(__FILE__,__LINE__,val)
 
 
+using ConfigOptionList = std::vector< std::unique_ptr<ConfigOption> >;
+using ConfigOptionMap  = std::unordered_map< std::string, ConfigOption* >;
+
 /** Singleton for configuration variables.
  *
  *  This object holds the global static variables
  *  read from a user-supplied configuration file.
  *  The static member instance() can be used to get
  *  a pointer to the one and only instance.
- *  
+ *
  *  Set all variables to their default values by
  *  calling Config::instance()->init()
  *
@@ -319,45 +351,37 @@ class ConfigImpl
       delete m_instance;
       m_instance=0;
     }
-    
-    /*! Returns an iterator that can by used to iterate over the 
-     *  configuration options.
-     */
-    QListIterator<ConfigOption> iterator()
-    {
-      return QListIterator<ConfigOption>(*m_options);
-    }
 
-    /*! 
+    /*!
      *  @name Getting configuration values.
      *  @{
      */
 
-    /*! Returns the value of the string option with name \a fileName. 
+    /*! Returns the value of the string option with name \a fileName.
      *  The arguments \a num and \a name are for debugging purposes only.
      *  There is a convenience function Config_getString() for this.
      */
     QCString &getString(const char *fileName,int num,const char *name) const;
 
-    /*! Returns the value of the list option with name \a fileName. 
+    /*! Returns the value of the list option with name \a fileName.
      *  The arguments \a num and \a name are for debugging purposes only.
      *  There is a convenience function Config_getList() for this.
      */
-    QStrList &getList(const char *fileName,int num,const char *name) const;
+    StringVector &getList(const char *fileName,int num,const char *name) const;
 
-    /*! Returns the value of the enum option with name \a fileName. 
+    /*! Returns the value of the enum option with name \a fileName.
      *  The arguments \a num and \a name are for debugging purposes only.
      *  There is a convenience function Config_getEnum() for this.
      */
     QCString &getEnum(const char *fileName,int num,const char *name) const;
 
-    /*! Returns the value of the integer option with name \a fileName. 
+    /*! Returns the value of the integer option with name \a fileName.
      *  The arguments \a num and \a name are for debugging purposes only.
      *  There is a convenience function Config_getInt() for this.
      */
     int      &getInt(const char *fileName,int num,const char *name) const;
 
-    /*! Returns the value of the boolean option with name \a fileName. 
+    /*! Returns the value of the boolean option with name \a fileName.
      *  The arguments \a num and \a name are for debugging purposes only.
      *  There is a convenience function Config_getBool() for this.
      */
@@ -366,14 +390,15 @@ class ConfigImpl
     /*! Returns the ConfigOption corresponding with \a name or 0 if
      *  the option is not supported.
      */
-    ConfigOption *get(const char *name) const
+    ConfigOption *get(const QCString &name) const
     {
-      return m_dict->find(name); 
+      auto it = m_dict.find(name.str());
+      return it!=m_dict.end() ? it->second : nullptr;
     }
     /* @} */
 
-    /*! 
-     *  @name Adding configuration options. 
+    /*!
+     *  @name Adding configuration options.
      *  @{
      */
 
@@ -383,7 +408,7 @@ class ConfigImpl
     ConfigInfo   *addInfo(const char *name,const char *doc)
     {
       ConfigInfo *result = new ConfigInfo(name,doc);
-      m_options->append(result);
+      m_options.push_back(std::unique_ptr<ConfigOption>(result));
       return result;
     }
 
@@ -394,13 +419,13 @@ class ConfigImpl
                             const char *doc)
     {
       ConfigString *result = new ConfigString(name,doc);
-      m_options->append(result);
-      m_dict->insert(name,result);
+      m_options.push_back(std::unique_ptr<ConfigOption>(result));
+      m_dict.insert(std::make_pair(name,result));
       return result;
     }
 
     /*! Adds a new enumeration option with \a name and documentation \a doc
-     *  and initial value \a defVal. 
+     *  and initial value \a defVal.
      *  \returns An object representing the option.
      */
     ConfigEnum   *addEnum(const char *name,
@@ -408,8 +433,8 @@ class ConfigImpl
                           const char *defVal)
     {
       ConfigEnum *result = new ConfigEnum(name,doc,defVal);
-      m_options->append(result);
-      m_dict->insert(name,result);
+      m_options.push_back(std::unique_ptr<ConfigOption>(result));
+      m_dict.insert(std::make_pair(name,result));
       return result;
     }
 
@@ -420,8 +445,8 @@ class ConfigImpl
                           const char *doc)
     {
       ConfigList *result = new ConfigList(name,doc);
-      m_options->append(result);
-      m_dict->insert(name,result);
+      m_options.push_back(std::unique_ptr<ConfigOption>(result));
+      m_dict.insert(std::make_pair(name,result));
       return result;
     }
 
@@ -435,8 +460,8 @@ class ConfigImpl
                          int minVal,int maxVal,int defVal)
     {
       ConfigInt *result = new ConfigInt(name,doc,minVal,maxVal,defVal);
-      m_options->append(result);
-      m_dict->insert(name,result);
+      m_options.push_back(std::unique_ptr<ConfigOption>(result));
+      m_dict.insert(std::make_pair(name,result));
       return result;
     }
 
@@ -449,25 +474,25 @@ class ConfigImpl
                           bool defVal)
     {
       ConfigBool *result = new ConfigBool(name,doc,defVal);
-      m_options->append(result);
-      m_dict->insert(name,result);
+      m_options.push_back(std::unique_ptr<ConfigOption>(result));
+      m_dict.insert(std::make_pair(name,result));
       return result;
     }
     /*! Adds an option that has become obsolete. */
-    ConfigOption *addObsolete(const char *name)
+    ConfigOption *addObsolete(const char *name,ConfigOption::OptionType orgType)
     {
-      ConfigObsolete *option = new ConfigObsolete(name);
-      m_dict->insert(name,option);
-      m_obsolete->append(option);
-      return option;
+      ConfigObsolete *result = new ConfigObsolete(name,orgType);
+      m_obsolete.push_back(std::unique_ptr<ConfigOption>(result));
+      m_dict.insert(std::make_pair(name,result));
+      return result;
     }
     /*! Adds an option that has been disabled at compile time. */
     ConfigOption *addDisabled(const char *name)
     {
-      ConfigDisabled *option = new ConfigDisabled(name);
-      m_dict->insert(name,option);
-      m_disabled->append(option);
-      return option;
+      ConfigDisabled *result = new ConfigDisabled(name);
+      m_disabled.push_back(std::unique_ptr<ConfigOption>(result));
+      m_dict.insert(std::make_pair(name,result));
+      return result;
     }
     /*! @} */
 
@@ -475,12 +500,17 @@ class ConfigImpl
      *  is \c TRUE the description of each configuration option will
      *  be omitted.
      */
-    void writeTemplate(FTextStream &t,bool shortIndex,bool updateOnly);
+    void writeTemplate(TextStream &t,bool shortIndex,bool updateOnly);
 
     /*! Writes a the differences between the current configuration and the
      *  template configuration to stream \a t.
      */
-    void compareDoxyfile(FTextStream &t);
+    void compareDoxyfile(TextStream &t);
+
+    /*! Writes a the used settings of the current configuration as XML format
+     *  to stream \a t.
+     */
+    void writeXMLDoxyfile(TextStream &t);
 
     void setHeader(const char *header) { m_header = header; }
 
@@ -508,18 +538,17 @@ class ConfigImpl
     /*! Parse a configuration data in string \a str.
      *  \returns TRUE if successful, or FALSE if the string could not be
      *  parsed.
-     */ 
-    //bool parseString(const char *fn,const char *str);
-    bool parseString(const char *fn,const char *str,bool upd = FALSE);
+     */
+    bool parseString(const QCString &fn,const QCString &str,bool upd = FALSE);
 
     /*! Parse a configuration file with name \a fn.
-     *  \returns TRUE if successful, FALSE if the file could not be 
+     *  \returns TRUE if successful, FALSE if the file could not be
      *  opened or read.
-     */ 
-    bool parse(const char *fn,bool upd = FALSE);
+     */
+    bool parse(const QCString &fn,bool upd = FALSE);
 
     /*! Called from the constructor, will add doxygen's default options
-     *  to the configuration object 
+     *  to the configuration object
      */
     void create();
 
@@ -542,7 +571,7 @@ class ConfigImpl
     {
       QCString result=m_startComment;
       m_startComment.resize(0);
-      return result.replace(QRegExp("\r"),"");
+      return substitute(result,"\r","");
     }
     /*! Take the user comment and reset it internally
      *  \returns user comment
@@ -551,36 +580,25 @@ class ConfigImpl
     {
       QCString result=m_userComment;
       m_userComment.resize(0);
-      return result.replace(QRegExp("\r"),"");
+      return substitute(result,"\r","");
     }
 
   protected:
 
     ConfigImpl()
     {
-      m_options  = new QList<ConfigOption>;
-      m_obsolete = new QList<ConfigOption>;
-      m_disabled = new QList<ConfigOption>;
-      m_dict     = new QDict<ConfigOption>(257);
-      m_options->setAutoDelete(TRUE);
-      m_obsolete->setAutoDelete(TRUE);
-      m_disabled->setAutoDelete(TRUE);
       m_initialized = FALSE;
       create();
     }
    ~ConfigImpl()
     {
-      delete m_options;
-      delete m_obsolete;
-      delete m_disabled;
-      delete m_dict;
     }
 
   private:
-    QList<ConfigOption> *m_options;
-    QList<ConfigOption> *m_obsolete;
-    QList<ConfigOption> *m_disabled;
-    QDict<ConfigOption> *m_dict;
+    ConfigOptionList m_options;
+    ConfigOptionList m_obsolete;
+    ConfigOptionList m_disabled;
+    ConfigOptionMap  m_dict;
     static ConfigImpl *m_instance;
     QCString m_startComment;
     QCString m_userComment;
