@@ -26,7 +26,6 @@
 #include "dot.h"
 #include "dotdirdeps.h"
 #include "layout.h"
-#include "ftextstream.h"
 #include "config.h"
 #include "docparser.h"
 #include "definitionimpl.h"
@@ -38,21 +37,22 @@
 class DirDefImpl : public DefinitionMixin<DirDef>
 {
   public:
-    DirDefImpl(const char *path);
+    DirDefImpl(const QCString &path);
     virtual ~DirDefImpl();
 
     virtual DefType definitionType() const { return TypeDir; }
+    virtual CodeSymbolType codeSymbolType() const { return CodeSymbolType::Default; }
     virtual QCString getOutputFileBase() const;
     virtual QCString anchor() const { return QCString(); }
     virtual bool isLinkableInProject() const;
     virtual bool isLinkable() const;
     virtual QCString displayName(bool=TRUE) const { return m_dispName; }
-    virtual const QCString &shortName() const { return m_shortName; }
+    virtual const QCString shortName() const { return m_shortName; }
     virtual void addSubDir(DirDef *subdir);
-    virtual FileList *   getFiles() const        { return m_fileList; }
-    virtual void addFile(FileDef *fd);
+    virtual const FileList &getFiles() const { return m_fileList; }
+    virtual void addFile(const FileDef *fd);
     virtual const DirList &subDirs() const { return m_subdirs; }
-    virtual bool isCluster() const { return m_subdirs.size()>0; }
+    virtual bool hasSubdirs() const { return !m_subdirs.empty(); }
     virtual int level() const { return m_level; }
     virtual DirDef *parent() const { return m_parent; }
     virtual int dirCount() const { return m_dirCount; }
@@ -62,13 +62,14 @@ class DirDefImpl : public DefinitionMixin<DirDef>
     virtual QCString shortTitle() const;
     virtual bool hasDetailedDescription() const;
     virtual void writeDocumentation(OutputList &ol);
-    virtual void writeTagFile(FTextStream &t);
+    virtual void writeTagFile(TextStream &t);
     virtual void setDiskName(const QCString &name) { m_diskName = name; }
     virtual void sort();
     virtual void setParent(DirDef *parent);
+    virtual void setDirCount(int count);
     virtual void setLevel();
-    virtual void addUsesDependency(DirDef *usedDir,FileDef *srcFd,
-                           FileDef *dstFd,bool inherited);
+    virtual void addUsesDependency(const DirDef *usedDir,const FileDef *srcFd,
+                                   const FileDef *dstFd,bool srcDirect, bool dstDirect);
     virtual void computeDependencies();
 
   public:
@@ -84,21 +85,21 @@ class DirDefImpl : public DefinitionMixin<DirDef>
     void startMemberDeclarations(OutputList &ol);
     void endMemberDeclarations(OutputList &ol);
 
-    static DirDef *createNewDir(const char *path);
+    static DirDef *createNewDir(const QCString &path);
     static bool matchPath(const QCString &path,const StringVector &l);
 
     DirList m_subdirs;
     QCString m_dispName;
     QCString m_shortName;
     QCString m_diskName;
-    FileList *m_fileList;                 // list of files in the group
-    int m_dirCount;
+    FileList m_fileList;                 // list of files in the group
+    int m_dirCount = -1;
     int m_level;
     DirDef *m_parent;
     UsedDirLinkedMap m_usedDirs;
 };
 
-DirDef *createDirDef(const char *path)
+DirDef *createDirDef(const QCString &path)
 {
   return new DirDefImpl(path);
 }
@@ -107,9 +108,7 @@ DirDef *createDirDef(const char *path)
 //----------------------------------------------------------------------
 // method implementation
 
-static int g_dirCount=0;
-
-DirDefImpl::DirDefImpl(const char *path) : DefinitionMixin(path,1,1,path)
+DirDefImpl::DirDefImpl(const QCString &path) : DefinitionMixin(path,1,1,path)
 {
   bool fullPathNames = Config_getBool(FULL_PATH_NAMES);
   // get display name (stripping the paths mentioned in STRIP_FROM_PATH)
@@ -132,15 +131,12 @@ DirDefImpl::DirDefImpl(const char *path) : DefinitionMixin(path,1,1,path)
     m_dispName = m_dispName.left(m_dispName.length()-1);
   }
 
-  m_fileList   = new FileList;
-  m_dirCount   = g_dirCount++;
   m_level=-1;
   m_parent=0;
 }
 
 DirDefImpl::~DirDefImpl()
 {
-  delete m_fileList;
 }
 
 bool DirDefImpl::isLinkableInProject() const
@@ -165,25 +161,30 @@ void DirDefImpl::setParent(DirDef *p)
    m_parent=p;
 }
 
-void DirDefImpl::addFile(FileDef *fd)
+void DirDefImpl::setDirCount(int count)
 {
-  m_fileList->append(fd);
-  fd->setDirDef(this);
+  m_dirCount=count;
+}
+
+void DirDefImpl::addFile(const FileDef *fd)
+{
+  m_fileList.push_back(fd);
+  const_cast<FileDef*>(fd)->setDirDef(this);
 }
 
 void DirDefImpl::sort()
 {
   std::sort(m_subdirs.begin(), m_subdirs.end(), compareDirDefs);
-  m_fileList->sort();
+  std::sort(m_fileList.begin(), m_fileList.end(), compareFileDefs);
 }
 
 static QCString encodeDirName(const QCString &anchor)
 {
   // convert to md5 hash
   uchar md5_sig[16];
-  QCString sigStr(33);
-  MD5Buffer((const unsigned char *)anchor.data(),anchor.length(),md5_sig);
-  MD5SigToString(md5_sig,sigStr.rawData(),33);
+  char sigStr[33];
+  MD5Buffer(anchor.data(),anchor.length(),md5_sig);
+  MD5SigToString(md5_sig,sigStr);
   return sigStr;
 
   // old algorithm
@@ -212,7 +213,7 @@ static QCString encodeDirName(const QCString &anchor)
 QCString DirDefImpl::getOutputFileBase() const
 {
   //printf("DirDefImpl::getOutputFileBase() %s->dir_%s\n",
-  //    m_diskName.data(),encodeDirName(m_diskName).data());
+  //    qPrint(m_diskName),qPrint(encodeDirName(m_diskName)));
   return "dir_"+encodeDirName(m_diskName);
 }
 
@@ -227,7 +228,7 @@ void DirDefImpl::writeDetailedDescription(OutputList &ol,const QCString &title)
     ol.popGeneratorState();
     ol.pushGeneratorState();
       ol.disableAllBut(OutputGenerator::Html);
-      ol.writeAnchor(0,"details");
+      ol.writeAnchor(QCString(),"details");
     ol.popGeneratorState();
     ol.startGroupHeader();
     ol.parseText(title);
@@ -237,7 +238,7 @@ void DirDefImpl::writeDetailedDescription(OutputList &ol,const QCString &title)
     if (!briefDescription().isEmpty() && Config_getBool(REPEAT_BRIEF))
     {
       ol.generateDoc(briefFile(),briefLine(),this,0,briefDescription(),FALSE,FALSE,
-                     0,FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT));
+                     QCString(),FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT));
     }
     // separator between brief and details
     if (!briefDescription().isEmpty() && Config_getBool(REPEAT_BRIEF) &&
@@ -258,7 +259,7 @@ void DirDefImpl::writeDetailedDescription(OutputList &ol,const QCString &title)
     if (!documentation().isEmpty())
     {
       ol.generateDoc(docFile(),docLine(),this,0,documentation()+"\n",TRUE,FALSE,
-                     0,FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT));
+                     QCString(),FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT));
     }
   }
 }
@@ -267,17 +268,18 @@ void DirDefImpl::writeBriefDescription(OutputList &ol)
 {
   if (hasBriefDescription())
   {
-    DocRoot *rootNode = validatingParseDoc(
-         briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE,
-         0,FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT));
-    if (rootNode && !rootNode->isEmpty())
+    auto parser { createDocParser() };
+    auto ast    { validatingParseDoc(
+         *parser.get(), briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE,
+         QCString(),FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT)) };
+    if (!ast->isEmpty())
     {
       ol.startParagraph();
       ol.pushGeneratorState();
       ol.disableAllBut(OutputGenerator::Man);
       ol.writeString(" - ");
       ol.popGeneratorState();
-      ol.writeDoc(rootNode,this,0);
+      ol.writeDoc(ast.get(),this,0);
       ol.pushGeneratorState();
       ol.disable(OutputGenerator::RTF);
       ol.writeString(" \n");
@@ -288,7 +290,7 @@ void DirDefImpl::writeBriefDescription(OutputList &ol)
          )
       {
         ol.disableAllBut(OutputGenerator::Html);
-        ol.startTextLink(0,"details");
+        ol.startTextLink(QCString(),"details");
         ol.parseText(theTranslator->trMore());
         ol.endTextLink();
       }
@@ -296,7 +298,6 @@ void DirDefImpl::writeBriefDescription(OutputList &ol)
 
       ol.endParagraph();
     }
-    delete rootNode;
   }
   ol.writeSynopsis();
 }
@@ -309,7 +310,7 @@ void DirDefImpl::writeDirectoryGraph(OutputList &ol)
     DotDirDeps dirDep(this);
     if (!dirDep.isTrivial())
     {
-      msg("Generating dependency graph for directory %s\n",displayName().data());
+      msg("Generating dependency graph for directory %s\n",qPrint(displayName()));
       ol.disable(OutputGenerator::Man);
       //ol.startParagraph();
       ol.startDirDepGraph();
@@ -326,7 +327,7 @@ void DirDefImpl::writeSubDirList(OutputList &ol)
   int numSubdirs = 0;
   for(const auto dd : m_subdirs)
   {
-    if (dd->hasDocumentation() || dd->getFiles()->count()>0)
+    if (dd->hasDocumentation() || !dd->getFiles().empty())
     {
       numSubdirs++;
     }
@@ -341,13 +342,13 @@ void DirDefImpl::writeSubDirList(OutputList &ol)
     ol.startMemberList();
     for(const auto dd : m_subdirs)
     {
-      if (dd->hasDocumentation() || dd->getFiles()->count()==0)
+      if (dd->hasDocumentation() || !dd->getFiles().empty())
       {
         ol.startMemberDeclaration();
-        ol.startMemberItem(dd->getOutputFileBase(),0);
+        ol.startMemberItem(dd->anchor(),0);
         ol.parseText(theTranslator->trDir(FALSE,TRUE)+" ");
         ol.insertMemberAlign();
-        ol.writeObjectLink(dd->getReference(),dd->getOutputFileBase(),0,dd->shortName());
+        ol.writeObjectLink(dd->getReference(),dd->getOutputFileBase(),QCString(),dd->shortName());
         ol.endMemberItem();
         if (!dd->briefDescription().isEmpty() && Config_getBool(BRIEF_MEMBER_DESC))
         {
@@ -355,14 +356,14 @@ void DirDefImpl::writeSubDirList(OutputList &ol)
           ol.generateDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),
               FALSE, // indexWords
               FALSE, // isExample
-              0,     // exampleName
+              QCString(), // exampleName
               TRUE,  // single line
               TRUE,  // link from index
               Config_getBool(MARKDOWN_SUPPORT)
               );
           ol.endMemberDescription();
         }
-        ol.endMemberDeclaration(0,0);
+        ol.endMemberDeclaration(dd->anchor(),QCString());
       }
     }
 
@@ -373,11 +374,14 @@ void DirDefImpl::writeSubDirList(OutputList &ol)
 void DirDefImpl::writeFileList(OutputList &ol)
 {
   int numFiles = 0;
-  QListIterator<FileDef> it(*m_fileList);
-  FileDef *fd;
-  for (it.toFirst();(fd=it.current());++it)
+  for (const auto &fd : m_fileList)
   {
-    if (fd->hasDocumentation())
+    bool genSourceFile;
+    if (fileVisibleInIndex(fd,genSourceFile))
+    {
+      numFiles++;
+    }
+    else if (genSourceFile)
     {
       numFiles++;
     }
@@ -390,17 +394,19 @@ void DirDefImpl::writeFileList(OutputList &ol)
     ol.parseText(theTranslator->trFile(TRUE,FALSE));
     ol.endMemberHeader();
     ol.startMemberList();
-    for (it.toFirst();(fd=it.current());++it)
+    for (const auto &fd : m_fileList)
     {
-      if (fd->hasDocumentation())
+      bool doc,src;
+      doc = fileVisibleInIndex(fd,src);
+      if (doc || src)
       {
         ol.startMemberDeclaration();
-        ol.startMemberItem(fd->getOutputFileBase(),0);
+        ol.startMemberItem(fd->anchor(),0);
         ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
         ol.insertMemberAlign();
         if (fd->isLinkable())
         {
-          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,fd->name());
+          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),QCString(),fd->name());
         }
         else
         {
@@ -413,7 +419,7 @@ void DirDefImpl::writeFileList(OutputList &ol)
           ol.pushGeneratorState();
           ol.disableAllBut(OutputGenerator::Html);
           ol.docify(" ");
-          ol.startTextLink(fd->includeName(),0);
+          ol.startTextLink(fd->includeName(),QCString());
           ol.docify("[");
           ol.parseText(theTranslator->trCode());
           ol.docify("]");
@@ -427,14 +433,14 @@ void DirDefImpl::writeFileList(OutputList &ol)
           ol.generateDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),
               FALSE, // indexWords
               FALSE, // isExample
-              0,     // exampleName
+              QCString(), // exampleName
               TRUE,  // single line
               TRUE,  // link from index
               Config_getBool(MARKDOWN_SUPPORT)
               );
           ol.endMemberDescription();
         }
-        ol.endMemberDeclaration(0,0);
+        ol.endMemberDeclaration(fd->anchor(),QCString());
       }
     }
     ol.endMemberList();
@@ -458,20 +464,17 @@ QCString DirDefImpl::shortTitle() const
 
 bool DirDefImpl::hasDetailedDescription() const
 {
-  static bool repeatBrief = Config_getBool(REPEAT_BRIEF);
+  bool repeatBrief = Config_getBool(REPEAT_BRIEF);
   return (!briefDescription().isEmpty() && repeatBrief) || !documentation().isEmpty();
 }
 
-void DirDefImpl::writeTagFile(FTextStream &tagFile)
+void DirDefImpl::writeTagFile(TextStream &tagFile)
 {
-  tagFile << "  <compound kind=\"dir\">" << endl;
-  tagFile << "    <name>" << convertToXML(displayName()) << "</name>" << endl;
-  tagFile << "    <path>" << convertToXML(name()) << "</path>" << endl;
-  tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << Doxygen::htmlFileExtension << "</filename>" << endl;
-  QListIterator<LayoutDocEntry> eli(
-      LayoutDocManager::instance().docEntries(LayoutDocManager::Directory));
-  LayoutDocEntry *lde;
-  for (eli.toFirst();(lde=eli.current());++eli)
+  tagFile << "  <compound kind=\"dir\">\n";
+  tagFile << "    <name>" << convertToXML(displayName()) << "</name>\n";
+  tagFile << "    <path>" << convertToXML(name()) << "</path>\n";
+  tagFile << "    <filename>" << addHtmlExtensionIfMissing(getOutputFileBase()) << "</filename>\n";
+  for (const auto &lde : LayoutDocManager::instance().docEntries(LayoutDocManager::Directory))
   {
     switch (lde->kind())
     {
@@ -481,21 +484,16 @@ void DirDefImpl::writeTagFile(FTextStream &tagFile)
           {
             for(const auto dd : m_subdirs)
             {
-              tagFile << "    <dir>" << convertToXML(dd->displayName()) << "</dir>" << endl;
+              tagFile << "    <dir>" << convertToXML(dd->displayName()) << "</dir>\n";
             }
           }
         }
         break;
       case LayoutDocEntry::DirFiles:
         {
-          if (m_fileList->count()>0)
+          for (const auto &fd : m_fileList)
           {
-            QListIterator<FileDef> it(*m_fileList);
-            FileDef *fd;
-            for (;(fd=it.current());++it)
-            {
-              tagFile << "    <file>" << convertToXML(fd->name()) << "</file>" << endl;
-            }
+              tagFile << "    <file>" << convertToXML(fd->name()) << "</file>\n";
           }
         }
         break;
@@ -504,12 +502,12 @@ void DirDefImpl::writeTagFile(FTextStream &tagFile)
     }
   }
   writeDocAnchorsToTagFile(tagFile);
-  tagFile << "  </compound>" << endl;
+  tagFile << "  </compound>\n";
 }
 
 void DirDefImpl::writeDocumentation(OutputList &ol)
 {
-  static bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
+  bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
   ol.pushGeneratorState();
 
   QCString title=theTranslator->trDirReference(m_dispName);
@@ -536,10 +534,7 @@ void DirDefImpl::writeDocumentation(OutputList &ol)
   //---------------------------------------- start flexible part -------------------------------
 
   SrcLangExt lang = getLanguage();
-  QListIterator<LayoutDocEntry> eli(
-      LayoutDocManager::instance().docEntries(LayoutDocManager::Directory));
-  LayoutDocEntry *lde;
-  for (eli.toFirst();(lde=eli.current());++eli)
+  for (const auto &lde : LayoutDocManager::instance().docEntries(LayoutDocManager::Directory))
   {
     switch (lde->kind())
     {
@@ -563,8 +558,11 @@ void DirDefImpl::writeDocumentation(OutputList &ol)
         break;
       case LayoutDocEntry::DetailedDesc:
         {
-          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
-          writeDetailedDescription(ol,ls->title(lang));
+          const LayoutDocEntrySection *ls = dynamic_cast<const LayoutDocEntrySection*>(lde.get());
+          if (ls)
+          {
+            writeDetailedDescription(ol,ls->title(lang));
+          }
         }
         break;
       case LayoutDocEntry::ClassIncludes:
@@ -577,11 +575,14 @@ void DirDefImpl::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::NamespaceNestedNamespaces:
       case LayoutDocEntry::NamespaceNestedConstantGroups:
       case LayoutDocEntry::NamespaceClasses:
+      case LayoutDocEntry::NamespaceConcepts:
       case LayoutDocEntry::NamespaceInterfaces:
       case LayoutDocEntry::NamespaceStructs:
       case LayoutDocEntry::NamespaceExceptions:
       case LayoutDocEntry::NamespaceInlineClasses:
+      case LayoutDocEntry::ConceptDefinition:
       case LayoutDocEntry::FileClasses:
+      case LayoutDocEntry::FileConcepts:
       case LayoutDocEntry::FileInterfaces:
       case LayoutDocEntry::FileStructs:
       case LayoutDocEntry::FileExceptions:
@@ -593,6 +594,7 @@ void DirDefImpl::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::FileSourceLink:
       case LayoutDocEntry::FileInlineClasses:
       case LayoutDocEntry::GroupClasses:
+      case LayoutDocEntry::GroupConcepts:
       case LayoutDocEntry::GroupInlineClasses:
       case LayoutDocEntry::GroupNamespaces:
       case LayoutDocEntry::GroupDirs:
@@ -640,29 +642,30 @@ void DirDefImpl::setLevel()
 
 /** Add as "uses" dependency between \a this dir and \a dir,
  *  that was caused by a dependency on file \a fd.
+ *  srcDirect and dstDirect indicate if it is a direct dependencies (true) or if
+ *  the dependencies was indirect (e.g. a parent dir that has a child dir that has the dependencies)
  */
-void DirDefImpl::addUsesDependency(DirDef *dir,FileDef *srcFd,
-                               FileDef *dstFd,bool inherited)
+void DirDefImpl::addUsesDependency(const DirDef *dir,const FileDef *srcFd,
+                                   const FileDef *dstFd,bool srcDirect, bool dstDirect)
 {
   if (this==dir) return; // do not add self-dependencies
   //static int count=0;
   //printf("  %d add dependency %s->%s due to %s->%s\n",
-  //    count++,shortName().data(),
-  //    dir->shortName().data(),
-  //    srcFd->name().data(),
-  //    dstFd->name().data());
+  //    count++,qPrint(shortName()),
+  //    qPrint(dir->shortName()),
+  //    qPrint(srcFd->name()),
+  //    qPrint(dstFd->name()));
 
   // levels match => add direct dependency
   bool added=FALSE;
   UsedDir *usedDir = m_usedDirs.find(dir->getOutputFileBase());
   if (usedDir) // dir dependency already present
   {
-     const FilePair *usedPair = usedDir->findFilePair(
-         srcFd->getOutputFileBase()+dstFd->getOutputFileBase());
+     const FilePair *usedPair = usedDir->findFilePair(FilePair::key(srcFd,dstFd));
      if (usedPair==0) // new file dependency
      {
        //printf("  => new file\n");
-       usedDir->addFileDep(srcFd,dstFd);
+       usedDir->addFileDep(srcFd,dstFd, srcDirect, dstDirect);
        added=TRUE;
      }
      else
@@ -673,9 +676,9 @@ void DirDefImpl::addUsesDependency(DirDef *dir,FileDef *srcFd,
   else // new directory dependency
   {
     //printf("  => new file\n");
-    auto newUsedDir = std::make_unique<UsedDir>(dir,inherited);
-    newUsedDir->addFileDep(srcFd,dstFd);
-    usedDir = m_usedDirs.add(dir->getOutputFileBase(),std::move(newUsedDir));
+    auto newUsedDir = std::make_unique<UsedDir>(dir);
+    newUsedDir->addFileDep(srcFd,dstFd, srcDirect, dstDirect);
+    m_usedDirs.add(dir->getOutputFileBase(),std::move(newUsedDir));
     added=TRUE;
   }
   if (added)
@@ -683,12 +686,20 @@ void DirDefImpl::addUsesDependency(DirDef *dir,FileDef *srcFd,
     if (dir->parent())
     {
       // add relation to parent of used dir
-      addUsesDependency(dir->parent(),srcFd,dstFd,inherited);
+      addUsesDependency(dir->parent(),
+                        srcFd,
+                        dstFd,
+                        srcDirect,
+                        false); // indirect dependency on dest dir
     }
     if (parent())
     {
       // add relation for the parent of this dir as well
-      parent()->addUsesDependency(dir,srcFd,dstFd,TRUE);
+      parent()->addUsesDependency(dir,
+                                 srcFd,
+                                 dstFd,
+                                 false, // indirect dependency from source dir
+                                 dstDirect);
     }
   }
 }
@@ -697,35 +708,23 @@ void DirDefImpl::addUsesDependency(DirDef *dir,FileDef *srcFd,
  */
 void DirDefImpl::computeDependencies()
 {
-  FileList *fl = m_fileList;
-  if (fl)
+  for (const auto &fd : m_fileList)
   {
-    QListIterator<FileDef> fli(*fl);
-    FileDef *fd;
-    for (fli.toFirst();(fd=fli.current());++fli) // foreach file in dir dd
+    //printf("  File %s\n",qPrint(fd->name()));
+    //printf("** dir=%s file=%s\n",qPrint(shortName()),qPrint(fd->name()));
+    for (const auto &ii : fd->includeFileList())
     {
-      //printf("  File %s\n",fd->name().data());
-      //printf("** dir=%s file=%s\n",shortName().data(),fd->name().data());
-      QList<IncludeInfo> *ifl = fd->includeFileList();
-      if (ifl)
+      //printf("  > %s\n",qPrint(ii->includeName));
+      //printf("    #include %s\n",qPrint(ii->includeName));
+      if (ii.fileDef && ii.fileDef->isLinkable()) // linkable file
       {
-        QListIterator<IncludeInfo> ifli(*ifl);
-        IncludeInfo *ii;
-        for (ifli.toFirst();(ii=ifli.current());++ifli) // foreach include file
+        DirDef *usedDir = ii.fileDef->getDirDef();
+        if (usedDir)
         {
-          //printf("  > %s\n",ii->includeName.data());
-          //printf("    #include %s\n",ii->includeName.data());
-          if (ii->fileDef && ii->fileDef->isLinkable()) // linkable file
-          {
-            DirDef *usedDir = ii->fileDef->getDirDef();
-            if (usedDir)
-            {
-              // add dependency: thisDir->usedDir
-              //static int count=0;
-              //printf("      %d: add dependency %s->%s\n",count++,name().data(),usedDir->name().data());
-              addUsesDependency(usedDir,fd,ii->fileDef,FALSE);
-            }
-          }
+          // add dependency: thisDir->usedDir
+          //static int count=0;
+          //printf("      %d: add dependency %s->%s\n",count++,qPrint(name()),qPrint(usedDir->name()));
+          addUsesDependency(usedDir,fd,ii.fileDef,true,true);
         }
       }
     }
@@ -753,50 +752,48 @@ bool DirDefImpl::isParentOf(const DirDef *dir) const
 
 bool DirDefImpl::depGraphIsTrivial() const
 {
-  return m_usedDirs.empty();
+  return m_usedDirs.empty() && m_parent==nullptr;
 }
 
+
 //----------------------------------------------------------------------
 
-int FilePairDict::compareValues(const FilePair *left,const FilePair *right) const
+UsedDir::UsedDir(const DirDef *dir) :
+   m_dir(dir)
 {
-  int orderHi = qstricmp(left->source()->name(),right->source()->name());
-  if (orderHi!=0) return orderHi;
-  int orderLo = qstricmp(left->destination()->name(),right->destination()->name());
-  return orderLo;
-}
-
-//----------------------------------------------------------------------
-
-UsedDir::UsedDir(const DirDef *dir,bool inherited) :
-   m_dir(dir), m_filePairs(7), m_inherited(inherited)
-{
-  m_filePairs.setAutoDelete(TRUE);
 }
 
 UsedDir::~UsedDir()
 {
 }
 
-
-void UsedDir::addFileDep(FileDef *srcFd,FileDef *dstFd)
+void UsedDir::addFileDep(const FileDef *srcFd,const FileDef *dstFd, bool srcDirect, bool dstDirect)
 {
-  m_filePairs.append(srcFd->getOutputFileBase()+dstFd->getOutputFileBase(),
-                     new FilePair(srcFd,dstFd));
+  m_filePairs.add(FilePair::key(srcFd,dstFd),std::make_unique<FilePair>(srcFd,dstFd));
+  m_hasDirectDeps    = m_hasDirectDeps    || (srcDirect && dstDirect);
+  m_hasDirectSrcDeps = m_hasDirectSrcDeps || srcDirect;
+  m_hasDirectDstDeps = m_hasDirectDstDeps || dstDirect;
 }
 
 void UsedDir::sort()
 {
-  m_filePairs.sort();
+  std::sort(m_filePairs.begin(),
+            m_filePairs.end(),
+            [](const auto &left,const auto &right)
+            {
+              int orderHi = qstricmp(left->source()->name(),right->source()->name());
+              if (orderHi!=0) return orderHi<0;
+              int orderLo = qstricmp(left->destination()->name(),right->destination()->name());
+              return orderLo<0;
+            });
 }
 
-FilePair *UsedDir::findFilePair(const char *name)
+FilePair *UsedDir::findFilePair(const QCString &name)
 {
-  QCString n=name;
-  return n.isEmpty() ? 0 : m_filePairs.find(n);
+  return m_filePairs.find(name);
 }
 
-DirDef *DirDefImpl::createNewDir(const char *path)
+DirDef *DirDefImpl::createNewDir(const QCString &path)
 {
   ASSERT(path!=0);
   DirDef *dir = Doxygen::dirLinkedMap->find(path);
@@ -806,7 +803,7 @@ DirDef *DirDefImpl::createNewDir(const char *path)
             std::unique_ptr<DirDef>(
               createDirDef(path)));
     //printf("Adding new dir %s\n",path);
-    //printf("createNewDir %s short=%s\n",path,dir->shortName().data());
+    //printf("createNewDir %s short=%s\n",path,qPrint(dir->shortName()));
   }
   return dir;
 }
@@ -829,7 +826,7 @@ bool DirDefImpl::matchPath(const QCString &path,const StringVector &l)
  */
 DirDef *DirDefImpl::mergeDirectoryInTree(const QCString &path)
 {
-  //printf("DirDefImpl::mergeDirectoryInTree(%s)\n",path.data());
+  //printf("DirDefImpl::mergeDirectoryInTree(%s)\n",qPrint(path));
   int p=0,i=0;
   DirDef *dir=0;
   while ((i=path.find('/',p))!=-1)
@@ -846,6 +843,13 @@ DirDef *DirDefImpl::mergeDirectoryInTree(const QCString &path)
 
 //----------------------------------------------------------------------
 
+QCString FilePair::key(const FileDef *srcFd,const FileDef *dstFd)
+{
+  return srcFd->getOutputFileBase()+";"+dstFd->getOutputFileBase();
+}
+
+//----------------------------------------------------------------------
+
 static void writePartialDirPath(OutputList &ol,const DirDef *root,const DirDef *target)
 {
   if (target->parent()!=root)
@@ -853,7 +857,7 @@ static void writePartialDirPath(OutputList &ol,const DirDef *root,const DirDef *
     writePartialDirPath(ol,root,target->parent());
     ol.writeString("&#160;/&#160;");
   }
-  ol.writeObjectLink(target->getReference(),target->getOutputFileBase(),0,target->shortName());
+  ol.writeObjectLink(target->getReference(),target->getOutputFileBase(),QCString(),target->shortName());
 }
 
 static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef *fd)
@@ -865,7 +869,7 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
   }
   if (fd->isLinkable())
   {
-    ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,fd->name());
+    ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),QCString(),fd->name());
   }
   else
   {
@@ -877,16 +881,14 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
 
 void DirRelation::writeDocumentation(OutputList &ol)
 {
-  static bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
+  bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
   QCString shortTitle=theTranslator->trDirRelation(
-                      m_src->shortName()+" &rarr; "+
-                      m_dst->dir()->shortName());
+                      (m_src->shortName()+" &rarr; "+m_dst->dir()->shortName()));
   QCString title=theTranslator->trDirRelation(
-                 m_src->displayName()+" -> "+
-                 m_dst->dir()->shortName());
+                 (m_src->displayName()+" -> "+m_dst->dir()->shortName()));
   startFile(ol,getOutputFileBase(),getOutputFileBase(),
             title,HLI_None,!generateTreeView,m_src->getOutputFileBase());
 
@@ -909,9 +911,7 @@ void DirRelation::writeDocumentation(OutputList &ol)
   ol.writeString("</th>");
   ol.writeString("</tr>");
 
-  SDict<FilePair>::Iterator fpi(m_dst->filePairs());
-  FilePair *fp;
-  for (fpi.toFirst();(fp=fpi.current());++fpi)
+  for (const auto &fp : m_dst->filePairs())
   {
     ol.writeString("<tr class=\"dirtab\">");
     ol.writeString("<td class=\"dirtab\">");
@@ -945,7 +945,7 @@ static void computeCommonDirPrefix()
   {
     // start will full path of first dir
     path=(*it)->name();
-    int i=path.findRev('/',(int)path.length()-2);
+    int i=path.findRev('/',path.length()-2);
     path=path.left(i+1);
     bool done=FALSE;
     if (i==-1)
@@ -963,9 +963,9 @@ static void computeCommonDirPrefix()
           QCString dirName = dir->name();
           if (dirName.length()>path.length())
           {
-            if (qstrncmp(dirName,path,l)!=0) // dirName does not start with path
+            if (dirName.left(l)!=path) // dirName does not start with path
             {
-              i=path.findRev('/',(int)l-2);
+              i=path.findRev('/',l-2);
               if (i==-1) // no unique prefix -> stop
               {
                 path="";
@@ -982,7 +982,7 @@ static void computeCommonDirPrefix()
           {
             path=dir->name();
             l=path.length();
-            i=path.findRev('/',(int)l-2);
+            i=path.findRev('/',l-2);
             if (i==-1) // no unique prefix -> stop
             {
               path="";
@@ -1008,7 +1008,7 @@ static void computeCommonDirPrefix()
   {
     QCString diskName = dir->name().right(dir->name().length()-path.length());
     dir->setDiskName(diskName);
-    //printf("set disk name: %s -> %s\n",dir->name().data(),diskName.data());
+    //printf("set disk name: %s -> %s\n",qPrint(dir->name()),qPrint(diskName));
   }
 }
 
@@ -1019,7 +1019,6 @@ void buildDirectories()
   {
     for (const auto &fd : *fn)
     {
-      //printf("buildDirectories %s\n",fd->name().data());
       if (fd->getReference().isEmpty())
       {
         DirDef *dir;
@@ -1040,7 +1039,7 @@ void buildDirectories()
   for (const auto &dir : *Doxygen::dirLinkedMap)
   {
     QCString name = dir->name();
-    int i=name.findRev('/',(int)name.length()-2);
+    int i=name.findRev('/',name.length()-2);
     if (i>0)
     {
       DirDef *parent = Doxygen::dirLinkedMap->find(name.left(i+1));
@@ -1049,7 +1048,7 @@ void buildDirectories()
       {
         parent->addSubDir(dir.get());
         //printf("DirDefImpl::addSubdir(): Adding subdir\n%s to\n%s\n",
-        //  dir->displayName().data(), parent->displayName().data());
+        //  qPrint(dir->displayName()), qPrint(parent->displayName()));
       }
     }
   }
@@ -1064,7 +1063,24 @@ void buildDirectories()
   std::sort(Doxygen::dirLinkedMap->begin(),
             Doxygen::dirLinkedMap->end(),
             [](const auto &d1,const auto &d2)
-            { return qstricmp(d1->shortName(),d2->shortName()) < 0; });
+            {
+              QCString s1 = d1->shortName(), s2 = d2->shortName();
+              int i = qstricmp(s1,s2);
+              if (i==0) // if sort name are equal, sort on full path
+              {
+                QCString n1 = d1->name(), n2 = d2->name();
+                int n = qstricmp(n1,n2);
+                return n < 0;
+              }
+              return i < 0;
+            });
+
+  // set the directory count identifier
+  int dirCount=0;
+  for (const auto &dir : *Doxygen::dirLinkedMap)
+  {
+    dir->setDirCount(dirCount++);
+  }
 
   computeCommonDirPrefix();
 }
@@ -1076,13 +1092,13 @@ void computeDirDependencies()
   {
     dir->setLevel();
   }
+
   // compute uses dependencies between directories
   for (const auto &dir : *Doxygen::dirLinkedMap)
   {
-    //printf("computeDependencies for %s: #dirs=%d\n",dir->name().data(),Doxygen::directories.count());
+    //printf("computeDependencies for %s: #dirs=%d\n",qPrint(dir->name()),Doxygen::directories.count());
     dir->computeDependencies();
   }
-
 }
 
 void generateDirDocs(OutputList &ol)
