@@ -16,22 +16,18 @@
 #ifndef DIRDEF_H
 #define DIRDEF_H
 
-#include "linkedmap.h"
-#include "sortdict.h"
-#include "definition.h"
 
 #include <vector>
 #include <map>
-#include <qglobal.h>
-#include <qcstring.h>
 
+#include "qcstring.h"
+#include "linkedmap.h"
+#include "definition.h"
 
 class FileList;
-class QStrList;
 class FileDef;
 class OutputList;
 class UsedDir;
-class FTextStream;
 class FilePair;
 class FilePairDict;
 class DirDef;
@@ -45,23 +41,20 @@ bool compareDirDefs(const DirDef *item1, const DirDef *item2);
 class FilePair
 {
   public:
-    FilePair(FileDef *src,FileDef *dst) : m_src(src), m_dst(dst) {}
+    FilePair(const FileDef *src,const FileDef *dst) : m_src(src), m_dst(dst) {}
     const FileDef *source() const { return m_src; }
     const FileDef *destination() const { return m_dst; }
+    static QCString key(const FileDef *srcFd,const FileDef *dstFd);
   private:
-    FileDef *m_src;
-    FileDef *m_dst;
+    const FileDef *m_src;
+    const FileDef *m_dst;
 };
 
 // ------------------
 
-/** A sorted dictionary of FilePair objects. */
-class FilePairDict : public SDict<FilePair>
+/** A linked map of file pairs */
+class FilePairLinkedMap : public LinkedMap<FilePair>
 {
-  public:
-    FilePairDict(uint size) : SDict<FilePair>(size) {}
-  private:
-    int compareValues(const FilePair *item1,const FilePair *item2) const;
 };
 
 // ------------------
@@ -70,19 +63,45 @@ class FilePairDict : public SDict<FilePair>
 class UsedDir
 {
   public:
-    UsedDir(const DirDef *dir,bool inherited);
+    UsedDir(const DirDef *dir);
     virtual ~UsedDir();
-    void addFileDep(FileDef *srcFd,FileDef *dstFd);
-    FilePair *findFilePair(const char *name);
-    const FilePairDict &filePairs() const { return m_filePairs; }
+
+    /**
+     * Take up dependency between files.
+     * @param[in] srcFd dependent file which depends on dstFd
+     * @param[in] dstFd dependee file on which srcFd depends on
+     * @param[in] srcDirect true iff the source dependency was the direct (not inherited from a sub dir)
+     * @param[in] dstDirect true iff the destination dependency was direct (not inherited from a sub dir)
+     */
+    void addFileDep(const FileDef *srcFd,const FileDef *dstFd, bool srcDirect, bool dstDirect);
+    FilePair *findFilePair(const QCString &name);
+    const FilePairLinkedMap &filePairs() const { return m_filePairs; }
     const DirDef *dir() const { return m_dir; }
-    bool inherited() const { return m_inherited; }
+
+    /** Returns true iff any of the dependencies between source and destination files are
+     *  direct (i.e. not "inherited" from sub directories)
+     */
+    bool hasDirectDeps() const { return m_hasDirectDeps; }
+
+    /** Returns true iff any of the dependencies from the source file to the destination file are
+     *  directly coming from a file in the source directory (i.e. not inherited via sub directories)
+     */
+    bool hasDirectSrcDeps() const { return m_hasDirectSrcDeps; }
+
+    /** Returns true iff any of the dependencies from the source file to the destination file are
+     *  directly targeting a file in the destination directory (i.e. not inherited via sub directories)
+     */
+    bool hasDirectDstDeps() const { return m_hasDirectDstDeps; }
+
     void sort();
 
   private:
     const DirDef *m_dir;
-    FilePairDict m_filePairs;
-    bool m_inherited;
+    FilePairLinkedMap m_filePairs;
+
+    bool m_hasDirectDeps    = false;
+    bool m_hasDirectSrcDeps = false;
+    bool m_hasDirectDstDeps = false;
 };
 
 // ------------------
@@ -91,8 +110,6 @@ class UsedDir
 class DirDef : public DefinitionMutable, public Definition
 {
   public:
-    virtual ~DirDef() {}
-
     class UsedDirLinkedMap : public LinkedMap<UsedDir> {};
 
     // accessors
@@ -102,12 +119,12 @@ class DirDef : public DefinitionMutable, public Definition
     virtual bool isLinkableInProject() const = 0;
     virtual bool isLinkable() const = 0;
     virtual QCString displayName(bool=TRUE) const = 0;
-    virtual const QCString &shortName() const = 0;
+    virtual const QCString shortName() const = 0;
     virtual void addSubDir(DirDef *subdir) = 0;
-    virtual FileList *   getFiles() const = 0;
-    virtual void addFile(FileDef *fd) = 0;
+    virtual const FileList &getFiles() const = 0;
+    virtual void addFile(const FileDef *fd) = 0;
     virtual const DirList &subDirs() const = 0;
-    virtual bool isCluster() const = 0;
+    virtual bool hasSubdirs() const = 0;
     virtual int level() const = 0;
     virtual DirDef *parent() const = 0;
     virtual int dirCount() const = 0;
@@ -119,14 +136,15 @@ class DirDef : public DefinitionMutable, public Definition
 
     // generate output
     virtual void writeDocumentation(OutputList &ol) = 0;
-    virtual void writeTagFile(FTextStream &t) = 0;
+    virtual void writeTagFile(TextStream &t) = 0;
 
     virtual void setDiskName(const QCString &name) = 0;
+    virtual void setDirCount(int count) = 0;
     virtual void sort() = 0;
     virtual void setParent(DirDef *parent) = 0;
     virtual void setLevel() = 0;
-    virtual void addUsesDependency(DirDef *usedDir,FileDef *srcFd,
-                           FileDef *dstFd,bool inherited) = 0;
+    virtual void addUsesDependency(const DirDef *usedDir,const FileDef *srcFd,
+                                   const FileDef *dstFd,bool srcDirect, bool dstDirect) = 0;
     virtual void computeDependencies() = 0;
 };
 
@@ -171,6 +189,5 @@ class DirRelationLinkedMap : public LinkedMap<DirRelation>
 void buildDirectories();
 void generateDirDocs(OutputList &ol);
 void computeDirDependencies();
-void writeDirDependencyGraph(const char *file);
 
 #endif
