@@ -15,8 +15,9 @@
 
 #include <cstdlib>
 #include <cassert>
-
-#include <qdir.h>
+#include <sstream>
+#include <algorithm>
+#include <mutex>
 
 #include "config.h"
 #include "dot.h"
@@ -25,10 +26,10 @@
 #include "util.h"
 #include "portable.h"
 #include "message.h"
-#include "ftextstream.h"
 #include "doxygen.h"
 #include "language.h"
 #include "index.h"
+#include "dir.h"
 
 #define MAP_CMD "cmapx"
 
@@ -36,17 +37,18 @@
 
 static QCString g_dotFontPath;
 
-static void setDotFontPath(const char *path)
+static std::mutex g_dotManagerMutex;
+
+static void setDotFontPath(const QCString &path)
 {
   ASSERT(g_dotFontPath.isEmpty());
   g_dotFontPath = Portable::getenv("DOTFONTPATH");
   QCString newFontPath = Config_getString(DOT_FONTPATH);
-  QCString spath = path;
-  if (!newFontPath.isEmpty() && !spath.isEmpty())
+  if (!newFontPath.isEmpty() && !path.isEmpty())
   {
-    newFontPath.prepend(spath+Portable::pathListSeparator());
+    newFontPath.prepend(path+Portable::pathListSeparator());
   }
-  else if (newFontPath.isEmpty() && !spath.isEmpty())
+  else if (newFontPath.isEmpty() && !path.isEmpty())
   {
     newFontPath=path;
   }
@@ -73,21 +75,10 @@ static void unsetDotFontPath()
 
 //--------------------------------------------------------------------
 
-DotManager *DotManager::m_theInstance = 0;
-
 DotManager *DotManager::instance()
 {
-  if (!m_theInstance)
-  {
-    m_theInstance = new DotManager;
-  }
-  return m_theInstance;
-}
-
-void DotManager::deleteInstance()
-{
-  delete m_theInstance;
-  m_theInstance=0;
+  static DotManager theInstance;
+  return &theInstance;
 }
 
 DotManager::DotManager() : m_runners(), m_filePatchers()
@@ -99,7 +90,7 @@ DotManager::DotManager() : m_runners(), m_filePatchers()
   {
     for (i=0;i<dotNumThreads;i++)
     {
-      std::unique_ptr<DotWorkerThread> thread = std::make_unique<DotWorkerThread>(m_queue);
+      DotWorkerThreadPtr thread(new DotWorkerThread(m_queue));
       thread->start();
       if (thread->isRunning())
       {
@@ -115,25 +106,26 @@ DotManager::DotManager() : m_runners(), m_filePatchers()
 
 DotManager::~DotManager()
 {
-  delete m_queue;
+  if (!Doxygen::terminating) delete m_queue;
 }
 
-DotRunner* DotManager::createRunner(const std::string &absDotName, const std::string& md5Hash)
+DotRunner* DotManager::createRunner(const QCString &absDotName, const QCString& md5Hash)
 {
+  std::lock_guard<std::mutex> lock(g_dotManagerMutex);
   DotRunner* rv = nullptr;
-  auto const runit = m_runners.find(absDotName);
+  auto const runit = m_runners.find(absDotName.str());
   if (runit == m_runners.end())
   {
     auto insobj = std::make_unique<DotRunner>(absDotName, md5Hash);
     rv = insobj.get();
-    m_runners.emplace(absDotName, std::move(insobj));
+    m_runners.emplace(absDotName.str(), std::move(insobj));
   }
   else
   {
     // we have a match
     if (md5Hash != runit->second->getMd5Hash())
     {
-      err("md5 hash does not match for two different runs of %s !\n", absDotName.data());
+      err("md5 hash does not match for two different runs of %s !\n", qPrint(absDotName));
     }
     rv = runit->second.get();
   }
@@ -141,13 +133,14 @@ DotRunner* DotManager::createRunner(const std::string &absDotName, const std::st
   return rv;
 }
 
-DotFilePatcher *DotManager::createFilePatcher(const std::string &fileName)
+DotFilePatcher *DotManager::createFilePatcher(const QCString &fileName)
 {
-  auto patcher = m_filePatchers.find(fileName);
+  std::lock_guard<std::mutex> lock(g_dotManagerMutex);
+  auto patcher = m_filePatchers.find(fileName.str());
 
   if (patcher != m_filePatchers.end()) return &(patcher->second);
 
-  auto rv = m_filePatchers.emplace(fileName, fileName.c_str());
+  auto rv = m_filePatchers.emplace(std::make_pair(fileName.str(), fileName));
   assert(rv.second);
   return &(rv.first->second);
 }
@@ -164,7 +157,7 @@ bool DotManager::run() const
     }
     else
     {
-      msg("Generating dot graphs using %zu parallel threads...\n",QMIN(numDotRuns+numFilePatchers,m_workers.size()));
+      msg("Generating dot graphs using %zu parallel threads...\n",std::min(numDotRuns+numFilePatchers,m_workers.size()));
     }
   }
   size_t i=1;
@@ -270,34 +263,35 @@ bool DotManager::run() const
 
 //--------------------------------------------------------------------
 
-void writeDotGraphFromFile(const char *inFile,const char *outDir,
-                           const char *outFile,GraphOutputFormat format)
+void writeDotGraphFromFile(const QCString &inFile,const QCString &outDir,
+                           const QCString &outFile,GraphOutputFormat format,
+                           const QCString &srcFile,int srcLine)
 {
-  QDir d(outDir);
+  Dir d(outDir.str());
   if (!d.exists())
   {
-    term("Output dir %s does not exist!\n",outDir);
+    term("Output dir %s does not exist!\n",qPrint(outDir));
   }
 
   QCString imgExt = getDotImageExtension();
-  QCString imgName = (QCString)outFile+"."+imgExt;
-  QCString absImgName = d.absPath().utf8()+"/"+imgName;
-  QCString absOutFile = d.absPath().utf8()+"/"+outFile;
+  QCString imgName = QCString(outFile)+"."+imgExt;
+  QCString absImgName = QCString(d.absPath())+"/"+imgName;
+  QCString absOutFile = QCString(d.absPath())+"/"+outFile;
 
   DotRunner dotRun(inFile);
   if (format==GOF_BITMAP)
   {
-    dotRun.addJob(Config_getEnum(DOT_IMAGE_FORMAT),absImgName);
+    dotRun.addJob(Config_getEnumAsString(DOT_IMAGE_FORMAT),absImgName,srcFile,srcLine);
   }
   else // format==GOF_EPS
   {
     if (Config_getBool(USE_PDFLATEX))
     {
-      dotRun.addJob("pdf",absOutFile+".pdf");
+      dotRun.addJob("pdf",absOutFile+".pdf",srcFile,srcLine);
     }
     else
     {
-      dotRun.addJob("ps",absOutFile+".eps");
+      dotRun.addJob("ps",absOutFile+".eps",srcFile,srcLine);
     }
   }
 
@@ -319,26 +313,29 @@ void writeDotGraphFromFile(const char *inFile,const char *outDir,
  *  \param baseName the base name of the output files
  *  \param context the scope in which this graph is found (for resolving links)
  *  \param graphId a unique id for this graph, use for dynamic sections
+ *  \param srcFile the source file
+ *  \param srcLine the line number in the source file
  */
-void writeDotImageMapFromFile(FTextStream &t,
+void writeDotImageMapFromFile(TextStream &t,
                             const QCString &inFile, const QCString &outDir,
                             const QCString &relPath, const QCString &baseName,
-                            const QCString &context,int graphId)
+                            const QCString &context,int graphId,
+                            const QCString &srcFile,int srcLine)
 {
 
-  QDir d(outDir);
+  Dir d(outDir.str());
   if (!d.exists())
   {
-    term("Output dir %s does not exist!\n",outDir.data());
+    term("Output dir %s does not exist!\n",qPrint(outDir));
   }
 
   QCString mapName = baseName+".map";
   QCString imgExt = getDotImageExtension();
   QCString imgName = baseName+"."+imgExt;
-  QCString absOutFile = d.absPath().utf8()+"/"+mapName;
+  QCString absOutFile = QCString(d.absPath())+"/"+mapName;
 
-  DotRunner dotRun(inFile.data());
-  dotRun.addJob(MAP_CMD,absOutFile);
+  DotRunner dotRun(inFile);
+  dotRun.addJob(MAP_CMD,absOutFile,srcFile,srcLine);
   dotRun.preventCleanUp();
   if (!dotRun.run())
   {
@@ -347,7 +344,7 @@ void writeDotImageMapFromFile(FTextStream &t,
 
   if (imgExt=="svg") // vector graphics
   {
-    QCString svgName=outDir+"/"+baseName+".svg";
+    QCString svgName = outDir+"/"+baseName+".svg";
     DotFilePatcher::writeSVGFigureLink(t,relPath,baseName,svgName);
     DotFilePatcher patcher(svgName);
     patcher.addSVGConversion("",TRUE,context,TRUE,graphId);
@@ -355,18 +352,16 @@ void writeDotImageMapFromFile(FTextStream &t,
   }
   else // bitmap graphics
   {
-    QGString result;
-    FTextStream tt(&result);
-
+    TextStream tt;
     t << "<img src=\"" << relPath << imgName << "\" alt=\""
-      << imgName << "\" border=\"0\" usemap=\"#" << mapName << "\"/>" << endl;
+      << imgName << "\" border=\"0\" usemap=\"#" << mapName << "\"/>\n";
     DotFilePatcher::convertMapFile(tt, absOutFile, relPath ,TRUE, context);
-    if (!result.isEmpty())
+    if (!tt.empty())
     {
       t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">";
-      t << result;
-      t << "</map>" << endl;
+      t << tt.str();
+      t << "</map>\n";
     }
   }
-  d.remove(absOutFile);
+  d.remove(absOutFile.str());
 }
