@@ -3,8 +3,8 @@
  * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -22,14 +22,13 @@
 class FileCodeParser : public CodeParserInterface
 {
   public:
-    virtual ~FileCodeParser() {}
     void parseCode(CodeOutputInterface &codeOutIntf,
-                   const char *scopeName,
+                   const QCString &scopeName,
                    const QCString &input,
                    SrcLangExt lang,
                    bool isExampleBlock,
-                   const char *exampleName=0,
-                   FileDef *fileDef=0,
+                   const QCString &exampleName=QCString(),
+                   const FileDef *fileDef=0,
                    int startLine=-1,
                    int endLine=-1,
                    bool inlineFragment=FALSE,
