@@ -19,9 +19,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <qregexp.h>
-#include <qfile.h>
-#include <qfileinfo.h>
 
 #include "htmlhelp.h"
 #include "config.h"
@@ -34,6 +31,8 @@
 #include "filedef.h"
 #include "util.h"
 #include "linkedmap.h"
+#include "regex.h"
+#include "fileinfo.h"
 
 //----------------------------------------------------------------------------
 
@@ -50,12 +49,12 @@ class HtmlHelpRecoder
 
     void initialize()
     {
-      const char *str = Config_getString(CHM_INDEX_ENCODING);
-      if (!str) str = "CP1250"; // use safe and likely default
-      m_fromUtf8 = portable_iconv_open(str,"UTF-8");
+      QCString str = Config_getString(CHM_INDEX_ENCODING);
+      if (str.isEmpty()) str = "CP1250"; // use safe and likely default
+      m_fromUtf8 = portable_iconv_open(str.data(),"UTF-8");
       if (m_fromUtf8==m_iconv_null)
       {
-        term("unsupported character conversion for CHM_INDEX_ENCODING: '%s'->'UTF-8'\n", str);
+        term("unsupported character conversion for CHM_INDEX_ENCODING: '%s'->'UTF-8'\n", qPrint(str));
       }
     }
     void finalize()
@@ -69,16 +68,16 @@ class HtmlHelpRecoder
 
     QCString recode(const QCString &s)
     {
-      int iSize        = s.length();
-      int oSize        = iSize*4+1;
+      size_t iSize     = s.length();
+      size_t oSize     = iSize*4+1;
       QCString output(oSize);
       size_t iLeft     = iSize;
       size_t oLeft     = oSize;
-      char *iPtr       = s.rawData();
+      const char *iPtr = s.data();
       char *oPtr       = output.rawData();
       if (!portable_iconv(m_fromUtf8,&iPtr,&iLeft,&oPtr,&oLeft))
       {
-        oSize -= (int)oLeft;
+        oSize -= oLeft;
         output.resize(oSize+1);
         output.at(oSize)='\0';
         return output;
@@ -89,7 +88,7 @@ class HtmlHelpRecoder
       }
     }
   private:
-    void *m_iconv_null = (void*)(-1);
+    void *m_iconv_null = reinterpret_cast<void*>(-1);
     void *m_fromUtf8 = m_iconv_null;
 
 };
@@ -99,7 +98,7 @@ class HtmlHelpRecoder
 /** Class representing a field in the HTML help index. */
 struct IndexField
 {
-  IndexField(const char *k,const char *n,const char *u,const char *a,bool l,bool r) :
+  IndexField(const QCString &k,const QCString &n,const QCString &u,const QCString &a,bool l,bool r) :
     key(k), name(n), url(u), anchor(a), link(l), reversed(r) {}
   QCString key;
   QCString name;
@@ -117,10 +116,10 @@ class HtmlHelpIndex
   public:
     HtmlHelpIndex(HtmlHelpRecoder &recoder);
    ~HtmlHelpIndex();
-    void addItem(const char *first,const char *second,
-                 const char *url, const char *anchor,
+    void addItem(const QCString &first,const QCString &second,
+                 const QCString &url, const QCString &anchor,
                  bool hasLink,bool reversed);
-    void writeFields(FTextStream &t);
+    void writeFields(std::ostream &t);
     size_t size() const { return m_map.size(); }
   private:
     LinkedMap<IndexField> m_map;
@@ -150,22 +149,32 @@ HtmlHelpIndex::~HtmlHelpIndex()
  *  \param reversed TRUE if level1 is the member name and level2 the compound
  *         name.
  */
-void HtmlHelpIndex::addItem(const char *level1,const char *level2,
-                       const char *url,const char *anchor,bool hasLink,
+void HtmlHelpIndex::addItem(const QCString &level1,const QCString &level2,
+                       const QCString &url,const QCString &anchor,bool hasLink,
                        bool reversed)
 {
-  QCString key = level1;
-  if (level2) key+= (QCString)"?" + level2;
-  if (key.find(QRegExp("@[0-9]+"))!=-1) // skip anonymous stuff
+  static const reg::Ex re(R"(@\d+)");
+  std::string key = level1.str();
+  if (!level2.isEmpty()) key+= std::string("?") + level2.str();
+  if (reg::search(key,re)) // skip anonymous stuff
   {
     return;
   }
-  m_map.add(key+anchor,key,url,anchor,hasLink,reversed);
+  std::string key_anchor;
+  if (!anchor.isEmpty())
+  {
+    key_anchor = key+anchor.str();
+  }
+  else
+  {
+    key_anchor = key;
+  }
+  m_map.add(key_anchor.c_str(),key.c_str(),url,anchor,hasLink,reversed);
 }
 
 static QCString field2URL(const IndexField *f,bool checkReversed)
 {
-  QCString result = f->url + Doxygen::htmlFileExtension;
+  QCString result = addHtmlExtensionIfMissing(f->url);
   if (!f->anchor.isEmpty() && (!checkReversed || f->reversed))
   {
     // HTML Help needs colons in link anchors to be escaped in the .hhk file.
@@ -200,7 +209,7 @@ static QCString field2URL(const IndexField *f,bool checkReversed)
  *      b1     -> link to url#anchor
  *  </pre>
  */
-void HtmlHelpIndex::writeFields(FTextStream &t)
+void HtmlHelpIndex::writeFields(std::ostream &t)
 {
   std::sort(std::begin(m_map),
             std::end(m_map),
@@ -224,7 +233,7 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
     }
 
     { // finish old list at level 2
-      if (level2Started) t << "  </UL>" << endl;
+      if (level2Started) t << "  </UL>\n";
       level2Started=FALSE;
 
       // <Antony>
@@ -239,7 +248,9 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
       if (it_next!=std::end(m_map))
       {
         auto &fnext = *it_next;
-        nextLevel1 = fnext->name.left(fnext->name.find('?'));
+        int j = fnext->name.find('?');
+        if (j<0) j=0;
+        nextLevel1 = fnext->name.left(j);
       }
       if (!(level1 == prevLevel1 || level1 == nextLevel1))
       {
@@ -253,7 +264,7 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
         t << "  <LI><OBJECT type=\"text/sitemap\">";
         t << "<param name=\"Local\" value=\"" << field2URL(f.get(),FALSE);
         t << "\">";
-        t << "<param name=\"Name\" value=\"" << m_recoder.recode(level1) << "\">"
+        t << "<param name=\"Name\" value=\"" << convertToHtml(m_recoder.recode(level1),TRUE) << "\">"
            "</OBJECT>\n";
       }
       else
@@ -263,26 +274,26 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
           t << "  <LI><OBJECT type=\"text/sitemap\">";
           t << "<param name=\"Local\" value=\"" << field2URL(f.get(),TRUE);
           t << "\">";
-          t << "<param name=\"Name\" value=\"" << m_recoder.recode(level1) << "\">"
+          t << "<param name=\"Name\" value=\"" << convertToHtml(m_recoder.recode(level1),TRUE) << "\">"
                "</OBJECT>\n";
         }
         else
         {
           t << "  <LI><OBJECT type=\"text/sitemap\">";
-          t << "<param name=\"See Also\" value=\"" << m_recoder.recode(level1) << "\">";
-          t << "<param name=\"Name\" value=\"" << m_recoder.recode(level1) << "\">"
+          t << "<param name=\"See Also\" value=\"" << convertToHtml(m_recoder.recode(level1),TRUE) << "\">";
+          t << "<param name=\"Name\" value=\"" << convertToHtml(m_recoder.recode(level1),TRUE) << "\">"
                "</OBJECT>\n";
         }
       }
     }
     if (!level2Started && !level2.isEmpty())
     { // start new list at level 2
-      t << "  <UL>" << endl;
+      t << "  <UL>\n";
       level2Started=TRUE;
     }
     else if (level2Started && level2.isEmpty())
     { // end list at level 2
-      t << "  </UL>" << endl;
+      t << "  </UL>\n";
       level2Started=FALSE;
     }
     if (level2Started)
@@ -290,11 +301,11 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
       t << "    <LI><OBJECT type=\"text/sitemap\">";
       t << "<param name=\"Local\" value=\"" << field2URL(f.get(),FALSE);
       t << "\">";
-      t << "<param name=\"Name\" value=\"" << m_recoder.recode(level2) << "\">"
+      t << "<param name=\"Name\" value=\"" << convertToHtml(m_recoder.recode(level2),TRUE) << "\">"
          "</OBJECT>\n";
     }
   }
-  if (level2Started) t << "  </UL>" << endl;
+  if (level2Started) t << "  </UL>\n";
 }
 
 //----------------------------------------------------------------------------
@@ -304,15 +315,14 @@ class HtmlHelp::Private
   public:
     Private() : index(recoder) {}
     void createProjectFile();
-    QFile cf;
-    QFile kf;
-    FTextStream cts,kts;
+    std::ofstream cts,kts;
     bool ctsItemPresent = false;
     int dc = 0;
     StringSet indexFiles;
     StringSet imageFiles;
-    HtmlHelpIndex index;
+    StringSet styleFiles;
     HtmlHelpRecoder recoder;
+    HtmlHelpIndex index;
 };
 
 
@@ -328,104 +338,6 @@ HtmlHelp::~HtmlHelp()
 {
 }
 
-/* language codes for Html help
-   0x405 Czech
-   0x406 Danish
-   0x413 Dutch
-   0xC09 English (Australia)
-   0x809 English (Britain)
-   0x1009 English (Canada)
-   0x1809 English (Ireland)
-   0x1409 English (New Zealand)
-   0x1C09 English (South Africa)
-   0x409 English (United States)
-   0x40B Finnish
-   0x40C French
-   0x407 German
-   0x408 Greece
-   0x40E Hungarian
-   0x410 Italian
-   0x814 Norwegian
-   0x415 Polish
-   0x816 Portuguese(Portugal)
-   0x416 Portuguese(Brazil)
-   0x419 Russian
-   0x80A Spanish(Mexico)
-   0xC0A Spanish(Modern Sort)
-   0x40A Spanish(Traditional Sort)
-   0x41D Swedish
-   0x41F Turkey
-   0x411 Japanese
-   0x412 Korean
-   0x804 Chinese (PRC)
-   0x404 Chinese (Taiwan)
-
-   New LCIDs:
-   0x421 Indonesian
-   0x41A Croatian
-   0x418 Romanian
-   0x424 Slovenian
-   0x41B Slovak
-   0x422 Ukrainian
-   0x81A Serbian (Serbia, Latin)
-   0x403 Catalan
-   0x426 Latvian
-   0x427 Lithuanian
-   0x436 Afrikaans
-   0x42A Vietnamese
-   0x429 Persian (Iran)
-   0xC01 Arabic (Egypt) - I don't know which version of arabic is used inside translator_ar.h ,
-   so I have chosen Egypt at random
-
-*/
-static StringUnorderedMap s_languageDict =
-{
-  { "czech",       "0x405 Czech"                     },
-  { "danish",      "0x406 Danish"                    },
-  { "dutch",       "0x413 Dutch"                     },
-  { "finnish",     "0x40B Finnish"                   },
-  { "french",      "0x40C French"                    },
-  { "german",      "0x407 German"                    },
-  { "greek",       "0x408 Greece"                    },
-  { "hungarian",   "0x40E Hungarian"                 },
-  { "italian",     "0x410 Italian"                   },
-  { "norwegian",   "0x814 Norwegian"                 },
-  { "polish",      "0x415 Polish"                    },
-  { "portuguese",  "0x816 Portuguese(Portugal)"      },
-  { "brazilian",   "0x416 Portuguese(Brazil)"        },
-  { "russian",     "0x419 Russian"                   },
-  { "spanish",     "0x40A Spanish(Traditional Sort)" },
-  { "swedish",     "0x41D Swedish"                   },
-  { "turkish",     "0x41F Turkey"                    },
-  { "japanese",    "0x411 Japanese"                  },
-  { "japanese-en", "0x411 Japanese"                  },
-  { "korean",      "0x412 Korean"                    },
-  { "korean-en",   "0x412 Korean"                    },
-  { "chinese",     "0x804 Chinese (PRC)"             },
-  { "chinese-traditional", "0x404 Chinese (Taiwan)"  },
-  { "indonesian",  "0x421 Indonesian"                },
-  { "croatian",    "0x41A Croatian"                  },
-  { "romanian",    "0x418 Romanian"                  },
-  { "slovene",     "0x424 Slovenian"                 },
-  { "slovak",      "0x41B Slovak"                    },
-  { "ukrainian",   "0x422 Ukrainian"                 },
-  { "serbian",     "0x81A Serbian (Serbia, Latin)"   },
-  { "catalan",     "0x403 Catalan"                   },
-  { "lithuanian",  "0x427 Lithuanian"                },
-  { "afrikaans",   "0x436 Afrikaans"                 },
-  { "vietnamese",  "0x42A Vietnamese"                },
-  { "persian",     "0x429 Persian (Iran)"            },
-  { "arabic",      "0xC01 Arabic (Egypt)"            },
-  { "latvian",     "0x426 Latvian"                   },
-  { "macedonian",  "0x042f Macedonian (Former Yugoslav Republic of Macedonia)" },
-  { "armenian",    "0x42b Armenian"                  },
-  //Code for Esperanto should be as shown below but the htmlhelp compiler 1.3 does not support this
-  // (and no newer version is available).
-  //So do a fallback to the default language (see getLanguageString())
-  //{ "esperanto",   "0x48f Esperanto" },
-  { "serbian-cyrillic", "0xC1A Serbian (Serbia, Cyrillic)" }
-};
-
 /*! This will create a contents file (index.hhc) and a index file (index.hhk)
  *  and write the header of those files.
  *  It also creates a project file (index.hhp)
@@ -436,14 +348,13 @@ void HtmlHelp::initialize()
   p->recoder.initialize();
 
   /* open the contents file */
-  QCString fName = Config_getString(HTML_OUTPUT) + "/index.hhc";
-  p->cf.setName(fName);
-  if (!p->cf.open(IO_WriteOnly))
+  QCString fName = Config_getString(HTML_OUTPUT) + "/" + hhcFileName;
+  p->cts.open(fName.str(),std::ofstream::out | std::ofstream::binary);
+  if (!p->cts.is_open())
   {
-    term("Could not open file %s for writing\n",fName.data());
+    term("Could not open file %s for writing\n",qPrint(fName));
   }
   /* Write the header of the contents file */
-  p->cts.setDevice(&p->cf);
   p->cts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -451,15 +362,14 @@ void HtmlHelp::initialize()
          "</OBJECT>\n"
          "<UL>\n";
 
-  /* open the contents file */
-  fName = Config_getString(HTML_OUTPUT) + "/index.hhk";
-  p->kf.setName(fName);
-  if (!p->kf.open(IO_WriteOnly))
+  /* open the index file */
+  fName = Config_getString(HTML_OUTPUT) + "/" + hhkFileName;
+  p->kts.open(fName.str(),std::ofstream::out | std::ofstream::binary);
+  if (!p->kts.is_open())
   {
-    term("Could not open file %s for writing\n",fName.data());
+    term("Could not open file %s for writing\n",qPrint(fName));
   }
   /* Write the header of the contents file */
-  p->kts.setDevice(&p->kf);
   p->kts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -469,34 +379,15 @@ void HtmlHelp::initialize()
 
 }
 
-
-QCString HtmlHelp::getLanguageString()
-{
-  if (!theTranslator->idLanguage().isEmpty())
-  {
-    auto it = s_languageDict.find(theTranslator->idLanguage().str());
-    if (it!=s_languageDict.end())
-    {
-      return it->second;
-    }
-  }
-  // default language
-  return "0x409 English (United States)";
-}
-
-
-
 void HtmlHelp::Private::createProjectFile()
 {
   /* Write the project file */
-  QCString fName = Config_getString(HTML_OUTPUT) + "/index.hhp";
-  QFile f(fName);
-  if (f.open(IO_WriteOnly))
+  QCString fName = Config_getString(HTML_OUTPUT) + "/" + hhpFileName;
+  std::ofstream t(fName.str(),std::ofstream::out | std::ofstream::binary);
+  if (t.is_open())
   {
-    FTextStream t(&f);
-
-    const char *hhcFile = "\"index.hhc\"";
-    const char *hhkFile = "\"index.hhk\"";
+    QCString hhcFile = "\"" + hhcFileName  + "\"";
+    QCString hhkFile = "\"" + hhkFileName  + "\"";
     bool hhkPresent = index.size()>0;
     if (!ctsItemPresent) hhcFile = "";
     if (!hhkPresent) hhkFile = "";
@@ -509,16 +400,16 @@ void HtmlHelp::Private::createProjectFile()
     }
     t << "Compatibility=1.1\n"
          "Full-text search=Yes\n";
-    if (ctsItemPresent) t << "Contents file=index.hhc\n";
+    if (ctsItemPresent) t << "Contents file=" + hhcFileName + "\n";
     t << "Default Window=main\n"
          "Default topic=" << indexName << "\n";
-    if (hhkPresent) t << "Index file=index.hhk\n";
-    t << "Language=" << getLanguageString() << endl;
+    if (hhkPresent) t << "Index file=" + hhkFileName + "\n";
+    t << "Language=" << theTranslator->getLanguageString() << "\n";
     if (Config_getBool(BINARY_TOC)) t << "Binary TOC=YES\n";
     if (Config_getBool(GENERATE_CHI)) t << "Create CHI file=YES\n";
-    t << "Title=" << recoder.recode(Config_getString(PROJECT_NAME)) << endl << endl;
+    t << "Title=" << recoder.recode(Config_getString(PROJECT_NAME)) << "\n\n";
 
-    t << "[WINDOWS]" << endl;
+    t << "[WINDOWS]\n";
 
     // NOTE: the 0x10387e number is a set of bits specifying the buttons
     //       which should appear in the CHM viewer; that specific value
@@ -534,39 +425,43 @@ void HtmlHelp::Private::createProjectFile()
     {
       t << "main=\"" << recoder.recode(Config_getString(PROJECT_NAME)) << "\"," << hhcFile << ","
          << hhkFile << ",\"" << indexName << "\",\"" <<
-         indexName << "\",,,,,0x23520,,0x70387e,,,,,,,,0" << endl << endl;
+         indexName << "\",,,,,0x23520,,0x70387e,,,,,,,,0\n\n";
     }
     else
     {
       t << "main=\"" << recoder.recode(Config_getString(PROJECT_NAME)) << "\"," << hhcFile << ","
          << hhkFile << ",\"" << indexName << "\",\"" <<
-         indexName << "\",,,,,0x23520,,0x10387e,,,,,,,,0" << endl << endl;
+         indexName << "\",,,,,0x23520,,0x10387e,,,,,,,,0\n\n";
     }
 
-    t << "[FILES]" << endl;
+    t << "[FILES]\n";
     for (auto &s : indexFiles)
     {
-      t << s.c_str() << endl;
+      t << s.c_str() << "\n";
     }
     for (auto &s : imageFiles)
     {
-      t << QFileInfo(s.c_str()).fileName().data() << endl;
+      t << s.c_str() << "\n";
     }
-    f.close();
+    for (auto &s : styleFiles)
+    {
+      t << s.c_str() << "\n";
+    }
+    t.close();
   }
   else
   {
-    err("Could not open file %s for writing\n",fName.data());
+    err("Could not open file %s for writing\n",qPrint(fName));
   }
 }
 
-void HtmlHelp::addIndexFile(const char *s)
+void HtmlHelp::addIndexFile(const QCString &s)
 {
-  p->indexFiles.insert(s);
+  p->indexFiles.insert(s.str());
 }
 
 /*! Finalizes the HTML help. This will finish and close the
- *  contents file (index.hhc) and the index file (index.hhk).
+ *  htmlhelp contents file  and the htmlhelp index file.
  *  \sa initialize()
  */
 void HtmlHelp::finalize()
@@ -575,8 +470,7 @@ void HtmlHelp::finalize()
   p->cts << "</UL>\n";
   p->cts << "</BODY>\n";
   p->cts << "</HTML>\n";
-  p->cts.unsetDevice();
-  p->cf.close();
+  p->cts.close();
 
   p->index.writeFields(p->kts);
 
@@ -584,8 +478,7 @@ void HtmlHelp::finalize()
   p->kts << "</UL>\n";
   p->kts << "</BODY>\n";
   p->kts << "</HTML>\n";
-  p->kts.unsetDevice();
-  p->kf.close();
+  p->kts.close();
 
   p->createProjectFile();
 
@@ -625,14 +518,15 @@ void HtmlHelp::decContentsDepth()
  *  \param def not used.
  */
 void HtmlHelp::addContentsItem(bool isDir,
-                               const char *name,
-                               const char * /*ref*/,
-                               const char *file,
-                               const char *anchor,
+                               const QCString &name,
+                               const QCString & /*ref*/,
+                               const QCString &file,
+                               const QCString &anchor,
                                bool /* separateIndex */,
                                bool /* addToNavIndex */,
                                const Definition * /* def */)
 {
+  bool binaryTOC = Config_getBool(BINARY_TOC);
   // If we're using a binary toc then folders cannot have links.
   // Tried this and I didn't see any problems, when not using
   // the resetting of file and anchor the TOC works better
@@ -646,31 +540,35 @@ void HtmlHelp::addContentsItem(bool isDir,
   int i; for (i=0;i<p->dc;i++) p->cts << "  ";
   p->cts << "<LI><OBJECT type=\"text/sitemap\">";
   p->cts << "<param name=\"Name\" value=\"" << convertToHtml(p->recoder.recode(name),TRUE) << "\">";
-  if (file)      // made file optional param - KPW
+  if (!file.isEmpty())      // made file optional param - KPW
   {
-    if (file && (file[0]=='!' || file[0]=='^')) // special markers for user defined URLs
+    if (file[0]=='!' || file[0]=='^') // special markers for user defined URLs
     {
       p->cts << "<param name=\"";
       if (file[0]=='^') p->cts << "URL"; else p->cts << "Local";
       p->cts << "\" value=\"";
       p->cts << &file[1];
+      p->cts << "\">";
     }
     else
     {
-      p->cts << "<param name=\"Local\" value=\"";
-      p->cts << file << Doxygen::htmlFileExtension;
-      if (anchor) p->cts << "#" << anchor;
+      if (!(binaryTOC && isDir))
+      {
+        p->cts << "<param name=\"Local\" value=\"";
+        p->cts << addHtmlExtensionIfMissing(file);
+        if (!anchor.isEmpty()) p->cts << "#" << anchor;
+        p->cts << "\">";
+      }
     }
-    p->cts << "\">";
   }
   p->cts << "<param name=\"ImageNumber\" value=\"";
   if (isDir)  // added - KPW
   {
-    p->cts << (int)BOOK_CLOSED ;
+    p->cts << static_cast<int>(BOOK_CLOSED);
   }
   else
   {
-    p->cts << (int)TEXT;
+    p->cts << static_cast<int>(TEXT);
   }
   p->cts << "\">";
   p->cts << "</OBJECT>\n";
@@ -678,11 +576,11 @@ void HtmlHelp::addContentsItem(bool isDir,
 
 
 void HtmlHelp::addIndexItem(const Definition *context,const MemberDef *md,
-                            const char *sectionAnchor,const char *word)
+                            const QCString &sectionAnchor,const QCString &word)
 {
   if (md)
   {
-    static bool separateMemberPages = Config_getBool(SEPARATE_MEMBER_PAGES);
+    bool separateMemberPages = Config_getBool(SEPARATE_MEMBER_PAGES);
     if (context==0) // global member
     {
       if (md->getGroupDef())
@@ -693,24 +591,30 @@ void HtmlHelp::addIndexItem(const Definition *context,const MemberDef *md,
     if (context==0) return; // should not happen
 
     QCString cfname  = md->getOutputFileBase();
+    QCString argStr  = md->argsString();
     QCString cfiname = context->getOutputFileBase();
     QCString level1  = context->name();
-    QCString level2  = md->name();
+    QCString level2  = md->name() + argStr;
     QCString contRef = separateMemberPages ? cfname : cfiname;
     QCString memRef  = cfname;
-    QCString anchor  = sectionAnchor ? QCString(sectionAnchor) : md->anchor();
+    QCString anchor  = !sectionAnchor.isEmpty() ? sectionAnchor : md->anchor();
     p->index.addItem(level1,level2,contRef,anchor,TRUE,FALSE);
     p->index.addItem(level2,level1,memRef,anchor,TRUE,TRUE);
   }
   else if (context)
   {
-    QCString level1  = word ? QCString(word) : context->name();
-    p->index.addItem(level1,0,context->getOutputFileBase(),sectionAnchor,TRUE,FALSE);
+    QCString level1  = !word.isEmpty() ? word : context->name();
+    p->index.addItem(level1,QCString(),context->getOutputFileBase(),sectionAnchor,TRUE,FALSE);
   }
 }
 
-void HtmlHelp::addImageFile(const char *fileName)
+void HtmlHelp::addStyleSheetFile(const QCString &fileName)
 {
-  p->imageFiles.insert(fileName);
+  p->styleFiles.insert(fileName.str());
+}
+
+void HtmlHelp::addImageFile(const QCString &fileName)
+{
+  p->imageFiles.insert(fileName.str());
 }
 
