@@ -22,6 +22,8 @@
  *  the call to all output generators.
  */
 
+#include <atomic>
+
 #include "outputlist.h"
 #include "outputgen.h"
 #include "config.h"
@@ -137,10 +139,10 @@ void OutputList::popGeneratorState()
   }
 }
 
-void OutputList::generateDoc(const char *fileName,int startLine,
+void OutputList::generateDoc(const QCString &fileName,int startLine,
                   const Definition *ctx,const MemberDef * md,
                   const QCString &docStr,bool indexWords,
-                  bool isExample,const char *exampleName,
+                  bool isExample,const QCString &exampleName,
                   bool singleLine,bool linkFromIndex,
                   bool markdownSupport)
 {
@@ -152,27 +154,29 @@ void OutputList::generateDoc(const char *fileName,int startLine,
     if (og->isEnabled()) count++;
   }
 
-  // we want to validate irrespective of the number of output formats
-  // specified as:
-  // - when only XML format there should be warnings as well (XML has its own write routines)
-  // - no formats there should be warnings as well
-  DocRoot *root=0;
-  root = validatingParseDoc(fileName,startLine,
-                            ctx,md,docStr,indexWords,isExample,exampleName,
-                            singleLine,linkFromIndex,markdownSupport);
-  if (count>0) writeDoc(root,ctx,md,m_id);
-  delete root;
+  if (count>0)
+  {
+    // we want to validate irrespective of the number of output formats
+    // specified as:
+    // - when only XML format there should be warnings as well (XML has its own write routines)
+    // - no formats there should be warnings as well
+    auto parser { createDocParser() };
+    auto ast    { validatingParseDoc(*parser.get(),
+                                     fileName,startLine,
+                                     ctx,md,docStr,indexWords,isExample,exampleName,
+                                     singleLine,linkFromIndex,markdownSupport) };
+    if (ast) writeDoc(ast.get(),ctx,md,m_id);
+  }
 }
 
-void OutputList::writeDoc(DocRoot *root,const Definition *ctx,const MemberDef *md,int)
+void OutputList::writeDoc(const IDocNodeAST *ast,const Definition *ctx,const MemberDef *md,int)
 {
   for (const auto &og : m_outputs)
   {
     //printf("og->printDoc(extension=%s)\n",
-    //    ctx?ctx->getDefFileExtension().data():"<null>");
-    if (og->isEnabled()) og->writeDoc(root,ctx,md,m_id);
+    //    ctx?qPrint(ctx->getDefFileExtension()):"<null>");
+    if (og->isEnabled()) og->writeDoc(ast,ctx,md,m_id);
   }
-  VhdlDocGen::setFlowMember(0);
 }
 
 void OutputList::parseText(const QCString &textStr)
@@ -187,17 +191,16 @@ void OutputList::parseText(const QCString &textStr)
   // specified as:
   // - when only XML format there should be warnings as well (XML has its own write routines)
   // - no formats there should be warnings as well
-  DocText *root = validatingParseText(textStr);
+  auto parser { createDocParser() };
+  auto textNode { validatingParseText(*parser.get(), textStr) };
 
-  if (count>0)
+  if (textNode && count>0)
   {
     for (const auto &og : m_outputs)
     {
-      if (og->isEnabled()) og->writeDoc(root,0,0,m_id);
+      if (og->isEnabled()) og->writeDoc(textNode.get(),0,0,m_id);
     }
   }
-
-  delete root;
 }
 
 //--------------------------------------------------------------------------
