@@ -37,6 +37,10 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     }
     virtual QCString trISOLang()
     { return "hy"; }
+    virtual QCString getLanguageString()
+    {
+      return "0x42b Armenian";
+    }
 
     // --- Language translation methods -------------------
 
@@ -108,9 +112,9 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Ավտոմատ ստեղծված է ելքային կոդից, Doxygen-ի միջոցով, ";
-      if (s) result+=s+(QCString)" համար:";
+      if (!s.isEmpty()) result+=s+" համար:";
       return result;
     }
 
@@ -342,6 +346,10 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       {
         return "Տվյալների կառուցվածքներ";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Դասեր";
@@ -360,12 +368,6 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trExampleDocumentation()
     { return "Օրինակներ"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Էջեր"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Հղումների ձեռնարկ"; }
@@ -457,24 +459,20 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Ստեղծվել է "+date;
-      if (projName) result+=projName+QCString(" -ի համար,");
-      result+=(QCString)" հետևյալ համակարգով.";
+      QCString result=QCString("Ստեղծվել է ")+date;
+      if (!projName.isEmpty()) result+=projName+" -ի համար,";
+      result+=" հետևյալ համակարգով.";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
       return clName+QCString(" -ի ժառանգման գծագիրը.");
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Միայն ներքին օգտագործման համար"; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Զգուշացում"; }
@@ -545,11 +543,11 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                  ClassDef::CompoundType compType,
                                  bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isTemplate)
       {
         switch(compType)
@@ -583,13 +581,13 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       return fileName+QCString(" ֆայլեր");
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" անունների տարածություններ";
@@ -724,7 +722,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
         bool single)
     {
-      QCString result = (QCString)"Այս ";
+      QCString result = "Այս ";
       switch(compType)
       {
         case ClassDef::Class:      result+="դասի"; break;
@@ -787,14 +785,14 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)clName+"-ի համագործակցությունների գծագիր.";
+      return clName+"-ի համագործակցությունների գծագիր.";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)fName+"-ի ներառումների կախվածությունների գծագիր.";
+      return fName+"-ի ներառումների կախվածությունների գծագիր.";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1074,14 +1072,9 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Փաթեթ "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Փաթեթների ցուցակ";
+      return "Փաթեթ "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1316,14 +1309,18 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Փաթեթի ֆունկցիաներ";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Փաթեթի անդամներ";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Փաթեթի ստատիկ ֆունկցիաներ";
     }
@@ -1435,18 +1432,10 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     virtual QCString trDirectories()
     { return "Ֆայլադրաններ"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Այս ֆայլադարանների հիերարխիան կարգավորված է կոպտորեն, "
-			"բայց ոչ ամբողջապես, այբբենական կարգով.";
-	}
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+=" Ֆայլադարան"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1572,11 +1561,11 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (!isTemplate)
       {
         switch(compType)
@@ -1609,7 +1598,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       return QCString("Մոդուլ ") + namespaceName;
     }
@@ -1658,7 +1647,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Այս ";
+      QCString result="Այս ";
       switch(compType)
       {
         case ClassDef::Class:      result+="մոդուլի"; break;
@@ -1705,7 +1694,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" Կապ";
     }
@@ -1742,18 +1731,18 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Ֆայլը " + name + " ում";
+      return "Ֆայլը " + name + " ում";
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Ներառում է ֆայլը " + name + " ում";
+      return "Ներառում է ֆայլը " + name + " ում";
     }
 
     /** Compiles a date string.
@@ -1798,7 +1787,7 @@ class TranslatorArmenian : public TranslatorAdapter_1_8_0
     { return "Հեղինակային իրավունք"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return name + QCString("-ի ֆայլադարանների կախվածությունների գծագիր:"); }
 
 };
