@@ -72,6 +72,10 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     {
       return "es";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x40A Spanish(Traditional Sort)";
+    }
 
     // --- Language translation methods -------------------
 
@@ -135,9 +139,9 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Generado automáticamente por Doxygen";
-      if (s) result+=(QCString)" para "+s;
+      if (!s.isEmpty()) result+=" para "+s;
       result+=" del código fuente.";
       return result;
     }
@@ -383,6 +387,10 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
       {
         return "Documentación de las estructuras de datos";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Documentación de las clases";
@@ -401,12 +409,6 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     virtual QCString trExampleDocumentation()
     { return "Documentación de ejemplos"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Documentación de páginas"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Manual de referencia"; }
@@ -495,24 +497,20 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Generado el "+date;
-      if (projName) result+=(QCString)" para "+projName;
-      result+=(QCString)" por";
+      QCString result="Generado el "+date;
+      if (!projName.isEmpty()) result+=" para "+projName;
+      result+=" por";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de herencias de "+clName;
+      return "Diagrama de herencias de "+clName;
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Sólo para uso interno."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Atención"; }
@@ -583,7 +581,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                          ClassDef::CompoundType compType,
                                          bool isTemplate)
     {
@@ -600,12 +598,12 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
         case ClassDef::Exception:  result+=" la Excepción "; break;
         default: break;
       }
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result="Referencia del Archivo ";
       result+=fileName;
@@ -613,7 +611,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Referencia del Namespace ";
       result+=namespaceName;
@@ -756,10 +754,11 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"La documentación para est";
+      bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
+      QCString result="La documentación para est";
       switch(compType)
       {
-        case ClassDef::Class:      result+="a clase"; break;
+        case ClassDef::Class:      result+=vhdlOpt? "a unidades de diseño":"a clase"; break;
         case ClassDef::Struct:     result+="a estructura"; break;
         case ClassDef::Union:      result+="a unión"; break;
         case ClassDef::Interface:  result+="e interfaz"; break;
@@ -820,15 +819,15 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de colaboración para "+clName+":";
+      return "Diagrama de colaboración para "+clName+":";
     }
 
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Dependencia gráfica adjunta para "+fName+":";
+      return "Dependencia gráfica adjunta para "+fName+":";
     }
 
     /*! header that is put before the list of constructor/destructors. */
@@ -1139,16 +1138,11 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     }
 
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paquetes "+name;
+      return "Paquetes "+name;
     }
 
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Lista de Paquetes ";
-    }
 
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1410,15 +1404,19 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funciones del 'package'";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Miembros del 'package'";
+    }
 
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Funciones estáticas del 'package'";
     }
@@ -1535,18 +1533,10 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     virtual QCString trDirectories()
     { return "Directorios"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "La jeraquía de este directorio está ordenada"
-              " alfabéticamente, de manera aproximada:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     {
       QCString result="Referencia del directorio ";
       result+=dirName;
@@ -1684,7 +1674,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -1701,12 +1691,12 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
         case ClassDef::Exception:  result+=" la excepción"; break;
         default: break;
       }
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result="Referencia módulo ";
       result+=namespaceName;
@@ -1758,7 +1748,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
                                                  bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"La documentación para est";
+      QCString result="La documentación para est";
       switch(compType)
       {
     	case ClassDef::Class:      result+="e módulo"; break;
@@ -1809,7 +1799,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" relación";
     }
@@ -1846,18 +1836,18 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Fichero en "+name;
+      return "Fichero en "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Incluye ficheros en "+name;
+      return "Incluye ficheros en "+name;
     }
 
     /** Compiles a date string.
@@ -1903,7 +1893,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Gráfico de dependencias de directorios para ")+name+":"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1933,11 +1923,11 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString("Referencia del enum ") + QCString(name); }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" heredados desde "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -2018,23 +2008,23 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     { return "Grupos constantes"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" referencia de grupos constantes";
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Referencia servicio";
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" referencia Singleton";
       return result;
     }
@@ -2042,7 +2032,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"La documentacion para este servicio "
+      QCString result="La documentacion para este servicio "
                                 "se ha generado desde ";
       if (single) result+="el siguiente fichero:"; else result+="los siguientes ficheros:";
       return result;
@@ -2051,7 +2041,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"La documentación para este singleton "
+      QCString result="La documentación para este singleton "
                                 "se ha generado desde ";
       if (single) result+="el siguiente fichero:"; else result+="los siguientes ficheros:";
       return result;
@@ -2171,7 +2161,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
           return "Clase";
       }
     }
-    virtual QCString trCustomReference(const char *name)
+    virtual QCString trCustomReference(const QCString &name)
     { return "Referencia"+QCString(name); }
 
     virtual QCString trConstants()
@@ -2270,7 +2260,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
     {
         return "Documentación de excepción";
     }
-    virtual QCString trCompoundReferenceSlice(const char *clName, ClassDef::CompoundType compType, bool isLocal)
+    virtual QCString trCompoundReferenceSlice(const QCString &clName, ClassDef::CompoundType compType, bool isLocal)
     {
       QCString result="Referencia de";
       switch(compType)
@@ -2285,7 +2275,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_8_15
         default: break;
       }
       if (isLocal) result+=" Local";
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
     virtual QCString trOperations()
