@@ -22,7 +22,10 @@
  * 01 Jan 2009 : Greek maintenance by
  *               Paul Gessos <gessos.paul@gmail.com>
  *
- * Last update : 06 Jan 2015
+ *
+ * Δουλεύω με C, C++, Java, PHP και Python. Άλλες γλώσσες (π.χ. VHDL) μου είναι
+ * άγνωστες.
+ * Αν παρατηρήσετε σφάλματα ΠΑΡΑΚΑΛΩ ΠΟΛΥ επικοινωνήστε μαζί μου.
  */
 
 /*	English to Greek keyword dictionary
@@ -36,13 +39,16 @@
 	exception -> εξαίρεση
 	namespace -> χώρος ονομάτων
 	enumeration -> απαρίθμηση
+	concept -> έννοια
+	signal -> σήμα
+	instantiation -> ενσάρκωση
 */
 
 
 #ifndef TRANSLATOR_GR_H
 #define TRANSLATOR_GR_H
 
-class TranslatorGreek : public TranslatorAdapter_1_8_15
+class TranslatorGreek : public TranslatorAdapter_1_9_4
 {
   public:
 
@@ -140,9 +146,9 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Δημιουργήθηκε αυτόματα από το Doxygen";
-      if (s) result+=(QCString)" για "+s;
+      if (!s.isEmpty()) result+=" για "+s;
       result+=" από τον πηγαίο κώδικα.";
       return result;
     }
@@ -247,6 +253,10 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
       {
         return "Ακολουθούν οι δομές δεδομένων με σύντομες περιγραφές:";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Ακολουθούν οι κλάσεις με σύντομες περιγραφές:";
+      }
       else
       {
         return "Ακολουθούν οι κλάσεις, οι δομές, "
@@ -385,6 +395,10 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
       {
         return "Τεκμηρίωση Δομών Δεδομένων";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Τεκμηρίωση Κλάσεων";
@@ -403,12 +417,6 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     virtual QCString trExampleDocumentation()
     { return "Τεκμηρίωση Παραδειγμάτων"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Τεκμηρίωση Σελίδων"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Εγχειρίδιο Τεκμηρίωσης"; }
@@ -497,24 +505,20 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Δημιουργήθηκε στις "+date;
-      if (projName) result+=(QCString)" για "+projName;
-      result+=(QCString)" από";
+      QCString result="Δημιουργήθηκε στις "+date;
+      if (!projName.isEmpty()) result+=" για "+projName;
+      result+=" από";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Διάγραμμα κληρονομικότητας για την "+clName+":";
+      return "Διάγραμμα κληρονομικότητας για την "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Μόνο για εσωτερική χρήση."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Προειδοποίηση"; }
@@ -585,11 +589,11 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)"Τεκμηρίωση";
+      QCString result="Τεκμηρίωση";
       if (isTemplate) result+=" Προτύπου";
       switch(compType)
       {
@@ -607,7 +611,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result="Τεκμηρίωση Αρχείου ";
       result+=fileName;
@@ -615,7 +619,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Τεκμηρίωση Χώρου Ονομάτων ";
       result+=namespaceName;
@@ -749,7 +753,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για ";
+      QCString result="Η τεκμηρίωση για ";
       switch(compType)
       {
         case ClassDef::Class:      result+="αυτή την κλάση"; break;
@@ -812,14 +816,14 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Διάγραμμα Συνεργασίας για την κλάση "+clName+":";
+      return "Διάγραμμα Συνεργασίας για την κλάση "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Διάγραμμα εξάρτησης αρχείου συμπερίληψης για το "+fName+":";
+      return "Διάγραμμα εξάρτησης αρχείου συμπερίληψης για το "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1100,14 +1104,9 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Πακέτο "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Λίστα Πακέτων";
+      return "Πακέτο "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1197,6 +1196,10 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     {
       return "Ευρετήριο";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x408 Greece";
+    }
 
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
@@ -1374,14 +1377,18 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Συναρτήσεις Πακέτου";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Μέλη Πακέτου";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Στατικές Συναρτήσεις Πακέτου";
     }
@@ -1493,18 +1500,10 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     virtual QCString trDirectories()
     { return "Κατάλογοι"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    {
-			return "Η ιεραρχία καταλόγων ταξινομήθηκε αλφαβητικά, αλλά όχι πολύ αυστηρά:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=QCString("Αναφορά του Καταλόγου ") + dirName; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1632,11 +1631,11 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Υπομονάδα"; break;
@@ -1653,7 +1652,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" Δηλώσεις Υπομονάδων";
@@ -1704,7 +1703,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για ";
+      QCString result="Η τεκμηρίωση για ";
       switch(compType)
       {
         case ClassDef::Class:      result+="αυτή την υπομονάδα"; break;
@@ -1753,7 +1752,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return "Σχέση του "+QCString(name);
     }
@@ -1790,18 +1789,18 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Αρχείο σε "+name;
+      return "Αρχείο σε "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Εσωκλείει το αρχείο στο "+name;
+      return "Εσωκλείει το αρχείο στο "+name;
     }
 
     /** Compiles a date string.
@@ -1844,7 +1843,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Διάγραμμα εξάρτησης φακέλων για ")+name+":"; }
 
 
@@ -1873,11 +1872,11 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
-    { return QCString("Αναφορά Απαρίθμησης ") + QCString(name); }
+    virtual QCString trEnumReference(const QCString &name)
+    { return QCString("Αναφορά Απαρίθμησης ") + name; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" κληρονόμησαν από "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1958,23 +1957,23 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     { return "Ομάδες Σταθερών"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" Τεκμηρίωση Ομάδας Σταθερών";
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Τεκμηρίωση Υπηρεσίας";
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Τεκμηρίωση Μονοσύνολου";
       return result;
     }
@@ -1982,7 +1981,7 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για την υπηρεσία αυτή "
+      QCString result="Η τεκμηρίωση για την υπηρεσία αυτή "
                                 "δημιουργήθηκε από ";
       if (single) result+="το ακόλουθο αρχείο:"; else result+="τα ακόλουθα αρχεία:";
       return result;
@@ -1991,13 +1990,314 @@ class TranslatorGreek : public TranslatorAdapter_1_8_15
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Η τεκμηρίωση για αυτό το μονοσύνολο "
+      QCString result="Η τεκμηρίωση για αυτό το μονοσύνολο "
                                 "δημιουργήθηκε από ";
       if (single) result+="το ακόλουθο αρχείο:"; else result+="τα ακόλουθα αρχεία:";
       return result;
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.15
+//////////////////////////////////////////////////////////////////////////
 
+    /** VHDL design unit hierarchy */
+    virtual QCString trDesignUnitHierarchy()
+    { return "Ιεραρχία Μονάδας Σχεδιασμού"; }
+    /** VHDL design unit list */
+    virtual QCString trDesignUnitList()
+    { return "Λίστα Μονάδας Σχεδιασμού"; }
+    /** VHDL design unit members */
+    virtual QCString trDesignUnitMembers()
+    { return "Μέλη Μονάδας Σχεδιασμού"; }
+    /** VHDL design unit list description */
+    virtual QCString trDesignUnitListDescription()
+    {
+        return "Ακολουθεί μια λίστα από τα μέλη της μονάδας σχεδιασμού με συνδέσμους στις Οντότητες στις οποίες ανήκουν:";
+    }
+    /** VHDL design unit index */
+    virtual QCString trDesignUnitIndex()
+    { return "Ευρετήριο Μονάδων Σχεδιασμού"; }
+    /** VHDL design units */
+    virtual QCString trDesignUnits()
+    { return "Μονάδες Σχεδιασμού"; }
+    /** VHDL functions/procedures/processes */
+    virtual QCString trFunctionAndProc()
+    { return "Συναρτήσεις/Διαδικασίες/Διεργασίες"; }
+    /** VHDL type */
+    virtual QCString trVhdlType(uint64 type,bool single)
+    {
+      switch(type)
+      {
+        case VhdlDocGen::LIBRARY:
+          if (single) return "Βιβλιοθήκη";
+          else        return "Βιβλιοθήκες";
+        case VhdlDocGen::PACKAGE:
+          if (single) return "Πακέτο";
+          else        return "Πακέτα";
+        case VhdlDocGen::SIGNAL:
+          if (single) return "Σήμα";
+          else        return "Σήματα";
+        case VhdlDocGen::COMPONENT:
+          if (single) return "Εξάρτημα";
+          else        return "Εξαρτήματα";
+        case VhdlDocGen::CONSTANT:
+          if (single) return "Σταθερά";
+          else        return "Σταθερές";
+        case VhdlDocGen::ENTITY:
+          if (single) return "Οντότητα";
+          else        return "Οντότητες";
+        case VhdlDocGen::TYPE:
+          if (single) return "Τύπος";
+          else        return "Τύποι";
+        case VhdlDocGen::SUBTYPE:
+          if (single) return "Υποτύπος";
+          else        return "Υποτύποι";
+        case VhdlDocGen::FUNCTION:
+          if (single) return "Συνάρτηση";
+          else        return "Συναρτήσεις";
+        case VhdlDocGen::RECORD:
+          if (single) return "Εγγραφή";
+          else        return "Εγγραφές";
+        case VhdlDocGen::PROCEDURE:
+          if (single) return "Διαδικασία";
+          else        return "Διαδικασίες";
+        case VhdlDocGen::ARCHITECTURE:
+          if (single) return "Αρχιτεκτονική";
+          else        return "Αρχιτεκτονικές";
+        case VhdlDocGen::ATTRIBUTE:
+          if (single) return "Ιδιότητα";
+          else        return "Ιδιότητες";
+        case VhdlDocGen::PROCESS:
+          if (single) return "Διεργασία";
+          else        return "Διεργασίες";
+        case VhdlDocGen::PORT:
+          if (single) return "Πόρτα";
+          else        return "Πόρτες";
+        case VhdlDocGen::USE:
+          if (single) return "χρήση διάταξης";
+          else        return "Χρήση Διατάξεων";
+        case VhdlDocGen::GENERIC:
+          if (single) return "Γενίκευση";
+          else        return "Γενικεύσεις";
+        case VhdlDocGen::PACKAGE_BODY:
+          return "Σώμα Πακέτου";
+        case VhdlDocGen::UNITS:
+          return "Μονάδες";
+        case VhdlDocGen::SHAREDVARIABLE:
+          if (single) return "Κοινόχρηστη Μεταβλητή";
+          else        return "Κοινόχρηστες Μεταβλητές";
+        case VhdlDocGen::VFILE:
+          if (single) return "Αρχείο";
+          else        return "Αρχεία";
+        case VhdlDocGen::GROUP:
+          if (single) return "Ομάδα";
+          else        return "Ομάδες";
+        case VhdlDocGen::INSTANTIATION:
+          if (single) return "Ενσάρκωση";
+          else        return "Ενσαρκώσεις";
+        case VhdlDocGen::ALIAS:
+          if (single) return "Συνώνυμο";
+          else        return "Συνώνυμα";
+        case VhdlDocGen::CONFIG:
+          if (single) return "Ρύθμιση";
+          else        return "Ρυθμίσεις";
+        case VhdlDocGen::MISCELLANEOUS:
+          return "Διάφορα";
+        case VhdlDocGen::UCF_CONST:
+          return "Εξαναγκασμοί";
+        default:
+          return "Κλάση";
+      }
+    }
+    virtual QCString trCustomReference(const QCString &name)
+    { return QCString("Τεκμηρίωση ")+name; }
+
+    /* Slice */
+    virtual QCString trConstants()
+    {
+        return "Σταθερές";
+    }
+    virtual QCString trConstantDocumentation()
+    {
+        return "Τεκμηρίωση Σταθεράς";
+    }
+    virtual QCString trSequences()
+    {
+        return "Ακολουθίες";
+    }
+    virtual QCString trSequenceDocumentation()
+    {
+        return "Τεκμηρίωση Ακολουθίας";
+    }
+    virtual QCString trDictionaries()
+    {
+        return "Λεξικά";
+    }
+    virtual QCString trDictionaryDocumentation()
+    {
+        return "Τεκμηρίωση Λεξικού";
+    }
+    virtual QCString trSliceInterfaces()
+    {
+        return "Διεπαφές";
+    }
+    virtual QCString trInterfaceIndex()
+    {
+        return "Ευρετήριο Διεπαφής";
+    }
+    virtual QCString trInterfaceList()
+    {
+        return "Λίστα Διεπαφής";
+    }
+    virtual QCString trInterfaceListDescription()
+    {
+        return "Ακολουθούν οι διεπαφές με σύντομες περιγραφές:";
+    }
+    virtual QCString trInterfaceHierarchy()
+    {
+        return "Ιεραρχία Διεπαφής";
+    }
+    virtual QCString trInterfaceHierarchyDescription()
+    {
+        return "Αυτή η λίστα ιεραρχίας είναι ταξινομημένη χονδροειδώς και όχι αυστηρά αλφαβητικά:";
+    }
+    virtual QCString trInterfaceDocumentation()
+    {
+        return "Τεκμηρίωση Διεπαφής";
+    }
+    virtual QCString trStructs()
+    {
+        return "Δομές";
+    }
+    virtual QCString trStructIndex()
+    {
+        return "Ευρετήριο Δομής";
+    }
+    virtual QCString trStructList()
+    {
+        return "Λίστα Δομής";
+    }
+    virtual QCString trStructListDescription()
+    {
+        return "Ακολουθούν οι δομές με σύντομες περιγραφές:";
+    }
+    virtual QCString trStructDocumentation()
+    {
+        return "Τεκμηρίωση Δομής";
+    }
+    virtual QCString trExceptionIndex()
+    {
+        return "Ευρετήριο Εξαιρέσεων";
+    }
+    virtual QCString trExceptionList()
+    {
+        return "Λίστα Εξαίρεσης";
+    }
+    virtual QCString trExceptionListDescription()
+    {
+        return "Ακολουθούν οι εξαιρέσεις με σύντομες περιγραφές:";
+    }
+    virtual QCString trExceptionHierarchy()
+    {
+        return "Ιεραρχία Εξαίρεσης";
+    }
+    virtual QCString trExceptionHierarchyDescription()
+    {
+        return "Αυτή η λίστα ιεραρχίας είναι ταξινομημένη χονδροειδώς και όχι αυστηρά αλφαβητικά:";
+    }
+    virtual QCString trExceptionDocumentation()
+    {
+        return "Τεκμηρίωση Εξαίρεσης";
+    }
+    virtual QCString trCompoundReferenceSlice(const QCString &clName, ClassDef::CompoundType compType, bool isLocal)
+    {
+      QCString result="Τεκμηρίωση ";
+      if (isLocal)
+		result+=compType == ClassDef::Protocol ? "Τοπικού " : "Τοπικής ";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="Κλάσης "; break;
+        case ClassDef::Struct:     result+="Δομής "; break;
+        case ClassDef::Union:      result+="Ένωσης "; break;
+        case ClassDef::Interface:  result+="Διεπαφής "; break;
+        case ClassDef::Protocol:   result+="Πρωτοκόλλου "; break;
+        case ClassDef::Category:   result+="Κατηγορίας "; break;
+        case ClassDef::Exception:  result+="Εξαίρεσης "; break;
+        default: break;
+      }
+      result+=clName;
+      return result;
+    }
+    virtual QCString trOperations()
+    {
+        return "Πράξεις";
+    }
+    virtual QCString trOperationDocumentation()
+    {
+        return "Τεκμηρίωση Πράξης";
+    }
+    virtual QCString trDataMembers()
+    {
+        return "Μέλη Δεδομένων";
+    }
+    virtual QCString trDataMemberDocumentation()
+    {
+        return "Τεκμηρίωση Μέλους Δεδομένων";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.19
+//////////////////////////////////////////////////////////////////////////
+
+    /** VHDL design unit documentation */
+    virtual QCString trDesignUnitDocumentation()
+    { return "Τεκμηρίωση Μονάδας Σχεδιασμού"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.2
+//////////////////////////////////////////////////////////////////////////
+
+    /** C++20 concept */
+    virtual QCString trConcept(bool first_capital, bool singular)
+    {
+      QCString result((first_capital ? "Έννοι" : "έννοι"));
+      result+=singular ? "α" : "ες";
+      return result;
+    }
+    /*! used as the title of the HTML page of a C++20 concept page */
+    virtual QCString trConceptReference(const QCString &conceptName)
+    {
+      QCString result("Αναφορά Έννοιας ");
+      result+=conceptName;
+      return result;
+    }
+
+    /*! used as the title of page containing all the index of all concepts. */
+    virtual QCString trConceptList()
+    { return "Λίστα Έννοιας"; }
+
+    /*! used as the title of chapter containing the index listing all concepts. */
+    virtual QCString trConceptIndex()
+    { return "Ευρετήριο Έννοιας"; }
+
+    /*! used as the title of chapter containing all information about concepts. */
+    virtual QCString trConceptDocumentation()
+    { return "Τεκμηρίωση Έννοιας"; }
+
+    /*! used as an introduction to the concept list */
+    virtual QCString trConceptListDescription(bool extractAll)
+    {
+      QCString result="Ακολουθεί μια λίστα από όλες τις ";
+      if (!extractAll) result+="τεκμηριωμένες ";
+      result+="έννοιες με σύντομες περιγραφές:";
+      return result;
+    }
+
+    /*! used to introduce the definition of the C++20 concept */
+    virtual QCString trConceptDefinition()
+    {
+      return "Ορισμός Έννοιας";
+    }
 };
 
 #endif
