@@ -104,6 +104,10 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     {
       return "hu";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x40E Hungarian";
+    }
 
     // --- Language translation methods -------------------
 
@@ -167,9 +171,9 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Ezt a dokumentációt a Doxygen készítette ";
-      if (s) result+=(QCString)" a" + zed(s[0])+s+(QCString)" projekthez";
+      if (!s.isEmpty()) result+=QCString(" a") + zed(s[0])+s+" projekthez";
       result+=" a forráskódból.";
       return result;
     }
@@ -418,6 +422,10 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
       {
         return "Adatszerkezetek dokumentációja";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Osztályok dokumentációja";
@@ -436,12 +444,6 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     virtual QCString trExampleDocumentation()
     { return "Példák dokumentációja"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Kapcsolódó dokumentációk"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Referencia kézikönyv"; }
@@ -530,24 +532,20 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"";
-      if (projName) result+=(QCString)"Projekt: "+projName;
-      result+=(QCString)" Készült: "+date+" Készítette: ";
+      QCString result="";
+      if (!projName.isEmpty()) result+="Projekt: "+projName;
+      result+=" Készült: "+date+" Készítette: ";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"A"+zed(clName[0])+clName+" osztály származási diagramja:";
+      return QCString("A")+zed(clName[0])+clName+" osztály származási diagramja:";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "CSAK BELSŐ HASZNÁLATRA!"; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Figyelmeztetés"; }
@@ -618,11 +616,11 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" osztály"; break;
@@ -640,7 +638,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result=fileName;
       result+=" fájlreferencia";
@@ -648,7 +646,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" névtér-referencia";
@@ -781,7 +779,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     virtual QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
         bool single)
     { // single is true implies a single file
-      QCString result=(QCString)"Ez a dokumentáció ";
+      QCString result="Ez a dokumentáció ";
       switch(compType)
       {
         case ClassDef::Class:      result+="az osztályról"; break;
@@ -845,14 +843,14 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"A"+zed(clName[0])+clName+" osztály együttműködési diagramja:";
+      return QCString("A")+zed(clName[0])+clName+" osztály együttműködési diagramja:";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"A"+zed(fName[0])+fName+" definíciós fájl függési gráfja:";
+      return QCString("A")+zed(fName[0])+fName+" definíciós fájl függési gráfja:";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1131,14 +1129,9 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return name+(QCString)" csomag";
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Csomaglista";
+      return name+" csomag";
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1396,14 +1389,18 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Csomag függvények";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Csomag tagok";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statikus csomag függvények";
     }
@@ -1515,18 +1512,10 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     virtual QCString trDirectories()
     { return "Könyvtárak"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Majdnem (de nem teljesen) betűrendbe szedett "
-             "könyvtárhierarchia:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+=" könyvtárreferencia"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1653,11 +1642,11 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" modul"; break;
@@ -1674,7 +1663,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" modul hivatkozás";
@@ -1726,7 +1715,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Ez a dokumentáció ";
+      QCString result="Ez a dokumentáció ";
       switch(compType)
       {
         case ClassDef::Class:      result+="a modulról"; break;
@@ -1777,7 +1766,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" kapcsolat";
     }
@@ -1814,18 +1803,18 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Fájl a(z) "+name+" könyvtárban";
+      return "Fájl a(z) "+name+" könyvtárban";
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Tartalmazott fájl a(z) "+name+" könyvtárban";
+      return "Tartalmazott fájl a(z) "+name+" könyvtárban";
     }
 
     /** Compiles a date string.
@@ -1868,7 +1857,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     { return "Szerzői jog"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Könyvtár függőségi gráf a(z) ")+name+"-könyvtárhoz:"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1896,11 +1885,11 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString(name)+" felsoroló referencia"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" a(z) "+what+" osztályból származnak"; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1981,23 +1970,23 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     { return "Konstans csoportok"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" konstans csoport referencia";
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" szolgáltatás referencia";
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" egyke példány referencia";
       return result;
     }
@@ -2005,7 +1994,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"A szolgáltatás dokumentációja "
+      QCString result="A szolgáltatás dokumentációja "
                                 "a következő fájl";
       if (single) result+="ból"; else result+="okból";
       result+="lett létrehozva:";
@@ -2015,7 +2004,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_8_15
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Az egyke példány dokomentációja "
+      QCString result="Az egyke példány dokomentációja "
                                 "a következő fájl";
       if (single) result+="ból"; else result+="okból";
       result+="lett létrehozva:";
