@@ -62,6 +62,10 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     {
       return "id";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x421 Indonesian";
+    }
 
     // --- Language translation methods -------------------
 
@@ -125,9 +129,9 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Dibangkitkan secara otomatis oleh Doxygen";
-      if (s) result+=(QCString)" untuk "+s;
+      if (!s.isEmpty()) result+=" untuk "+s;
       result+=" dari kode sumber.";
       return result;
     }
@@ -374,6 +378,10 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
       {
         return "Dokumentasi Struktur Data";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Dokumentasi Kelas";
@@ -392,12 +400,6 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     virtual QCString trExampleDocumentation()
     { return "Dokumentasi Contoh"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Dokumentasi Halaman"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Dokumen Referensi"; }
@@ -486,24 +488,20 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Dibangkitkan pada tanggal "+date;
-      if (projName) result+=(QCString)" untuk "+projName;
-      result+=(QCString)" oleh";
+      QCString result="Dibangkitkan pada tanggal "+date;
+      if (!projName.isEmpty()) result+=" untuk "+projName;
+      result+=" oleh";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Diagram hierarki kelas untuk "+clName+":";
+      return "Diagram hierarki kelas untuk "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Hanya untuk digunakan secara internal."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Peringatan"; }
@@ -574,7 +572,7 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
         ClassDef::CompoundType compType,
         bool isTemplate)
     {
@@ -591,12 +589,12 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
         default: break;
       }
       if (isTemplate) result+=" Template ";
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result="Referensi File ";
       result+=fileName;
@@ -604,7 +602,7 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Referensi Namespace ";
       result+=namespaceName;
@@ -738,7 +736,7 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentasi untuk ";
+      QCString result="Dokumentasi untuk ";
       switch(compType)
       {
         case ClassDef::Class:      result+="kelas"; break;
@@ -802,14 +800,14 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Diagram kolaborasi untuk "+clName+":";
+      return "Diagram kolaborasi untuk "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Bagan kebergantungan pemuatan untuk "+fName+":";
+      return "Bagan kebergantungan pemuatan untuk "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1086,14 +1084,9 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paket "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Daftar Paket";
+      return "Paket "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1350,14 +1343,18 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Daftar Fungsi Paket";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Anggota-anggota Paket";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Daftar Fungsi Statis Paket";
     }
@@ -1469,17 +1466,10 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     virtual QCString trDirectories()
     { return "Daftar Direktori"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Struktur direktori ini diurutkan hampir berdasarkan abjad:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result="Referensi Direktori "; result+=dirName; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1606,7 +1596,7 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -1623,11 +1613,11 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
         case ClassDef::Exception:  result+="Eksepsi "; break;
         default: break;
       }
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result="Referensi Modul ";
       result+=namespaceName;
@@ -1678,7 +1668,7 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentasi untuk ";
+      QCString result="Dokumentasi untuk ";
       switch(compType)
       {
         case ClassDef::Class:      result+="module"; break;
@@ -1727,7 +1717,7 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return "Relasi "+QCString(name);
     }
@@ -1764,18 +1754,18 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"File dimuat dalam "+name;
+      return "File dimuat dalam "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Memuat file dalam "+name;
+      return "Memuat file dalam "+name;
     }
 
     /** Compiles a date string.
@@ -1818,7 +1808,7 @@ class TranslatorIndonesian : public TranslatorAdapter_1_8_0
     { return "Hak Cipta"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Bagan dependensi directori untuk ")+name+":"; }
 
 };
