@@ -83,6 +83,10 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     {
       return "ja";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x411 Japanese";
+    }
     virtual QCString latexFontenc()
     {
       return "";
@@ -95,6 +99,10 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     {
       return "\\end{CJK}\n";
     }
+    virtual bool needsPunctuation()
+    {
+      return false;
+    }
 
     /*! used in the compound documentation before a list of related functions. */
     virtual QCString trRelatedFunctions()
@@ -167,9 +175,9 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result = "Doxygen により";
-      if (s) result=(QCString)" "+s+"の";
+      if (!s.isEmpty()) result=" "+s+"の";
       result+="ソースコードから抽出しました。";
       return result;
     }
@@ -424,6 +432,10 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
       {
         return "データ構造詳解";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "クラス詳解";
@@ -442,12 +454,6 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     virtual QCString trExampleDocumentation()
     { return "各例詳解"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "ページ詳解"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "リファレンスマニュアル"; }
@@ -534,24 +540,20 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result = (QCString)date+"作成";
-      if (projName) result+=(QCString)" - " + projName;
+      QCString result = date+"作成";
+      if (!projName.isEmpty()) result+=" - " + projName;
       result+=" / 構成: ";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)clName+" の継承関係図";
+      return clName+" の継承関係図";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "内部処理用です。"; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "警告"; }
@@ -623,11 +625,11 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                  ClassDef::CompoundType compType,
                                  bool isTemplate)
     {
-      QCString result=(QCString)clName+" ";
+      QCString result=clName+" ";
       switch(compType)
       {
         case ClassDef::Class:      result+="クラス"; break;
@@ -644,16 +646,16 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
-      QCString result=(QCString)fileName+" ファイル";
+      QCString result=fileName+" ファイル";
       return result;
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
-      QCString result=(QCString)namespaceName+" 名前空間";
+      QCString result=namespaceName+" 名前空間";
       return result;
     }
 
@@ -792,7 +794,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
         bool /*single*/)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"この";
+      QCString result="この";
       switch(compType)
       {
         case ClassDef::Class:      result+="クラス"; break;
@@ -850,14 +852,14 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     }
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)clName+" 連携図";
+      return clName+" 連携図";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-    return (QCString)fName+" の依存先関係図:";
+    return fName+" の依存先関係図:";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1128,14 +1130,9 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)name+" パッケージ";
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "パッケージ一覧";
+      return name+" パッケージ";
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1377,14 +1374,19 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "関数";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "パッケージ内のメンバ";
+    }
+
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "静的関数";
     }
@@ -1496,18 +1498,10 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     virtual QCString trDirectories()
     { return "ディレクトリ"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "このディレクトリ一覧はおおまかにはソートされていますが、"
-             "完全にアルファベット順でソートされてはいません。";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+=" ディレクトリリファレンス"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1634,7 +1628,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -1651,11 +1645,11 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
         default: break;
       }
       if (isTemplate) result += "テンプレート ";
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+="モジュール";
@@ -1744,7 +1738,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" 関係";
     }
@@ -1781,18 +1775,18 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)name+"にあるファイル";
+      return name+"にあるファイル";
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)name+"にあるファイルを include している";
+      return name+"にあるファイルを include している";
     }
 
     /** Compiles a date string.
@@ -1834,7 +1828,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     { return "著作権所有"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString(name)+" のディレクトリ依存関係図"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1860,11 +1854,11 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString("列挙 ")+name+" 詳解"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString("基底クラス ")+what+" に属する継承"+members; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1946,23 +1940,23 @@ class TranslatorJapanese : public TranslatorAdapter_1_8_15
     { return "定数グループ"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" 定数グループ詳解";
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" サービス詳解";
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Singleton 詳解";
       return result;
     }
