@@ -69,6 +69,10 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     {
       return "lt";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x427 Lithuanian";
+    }
 
     // --- Language translation methods -------------------
 
@@ -132,9 +136,9 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Automatiškai sugeneruota Doxygen įrankiu";
-      if (s) result+=(QCString)" "+s;
+      if (!s.isEmpty()) result+=" "+s;
       result+=" iš programos kodo.";
       return result;
     }
@@ -241,6 +245,10 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
       {
         return "Duomenų struktūros su trumpais aprašymais:";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Klasės su trumpais aprašymais:";
+      }
       else
       {
         return "Klasės, struktūros, "
@@ -378,6 +386,10 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
       {
         return "Duomenų Struktūros Dokumentacija";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Klasės Dokumentacija";
@@ -396,12 +408,6 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     virtual QCString trExampleDocumentation()
     { return "Pavyzdžio Dokumentacija"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Puslapio Dokumentacija"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Informacinis Vadovas"; }
@@ -490,24 +496,20 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Sugeneruota "+date;/*FIXME*/
-      if (projName) result+=(QCString)" "+projName;/*FIXME*/
-      result+=(QCString)" ";/*FIXME*/
+      QCString result="Sugeneruota "+date;/*FIXME*/
+      if (!projName.isEmpty()) result+=" "+projName;/*FIXME*/
+      result+=" ";/*FIXME*/
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Paveldimumo diagrama "+clName+":"; /*FIXME*/
+      return "Paveldimumo diagrama "+clName+":"; /*FIXME*/
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Tiktai vidiniam naudojimui."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Įspėjimas"; }
@@ -578,11 +580,11 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Klasė"; break;
@@ -599,7 +601,7 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result=fileName;
       result+=" Failo Nuoroda";
@@ -607,7 +609,7 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" Vardų Srities Nuoroda";
@@ -741,7 +743,7 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentacija ";
+      QCString result="Dokumentacija ";
       switch(compType)
       {
         case ClassDef::Class:      result+="šiai klasei"; break;
@@ -804,14 +806,14 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Bendradarbiavimo diagrama "+clName+":";/*FIXME*/
+      return "Bendradarbiavimo diagrama "+clName+":";/*FIXME*/
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Įtraukimo priklausomybių diagrama "+fName+":";/*FIXME*/
+      return "Įtraukimo priklausomybių diagrama "+fName+":";/*FIXME*/
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1090,14 +1092,9 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paketas "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Paketo Sąrašas";
+      return "Paketas "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1360,14 +1357,18 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Paketo Funkcijos";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Paketo Nariai";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statinės Paketo Funkcijos";
     }
@@ -1478,17 +1479,10 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
     virtual QCString trDirectories()
     { return "Direktorijos"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Ši direktorjų strūktūra grubiai surikiuota abėcėlės tvarka:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+=" Directorijos aprašas"; return result; }
 
     /*! This returns the word directory with or without starting capital
