@@ -58,6 +58,10 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     {
       return "pl";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x415 Polish";
+    }
 
     // --- Language translation methods -------------------
 
@@ -121,9 +125,9 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    QCString trGeneratedAutomatically(const char *s)
+    QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Wygenerowano automatycznie z kodu źródłowego programem Doxygen";
-      if (s) result+=(QCString)" dla "+s;
+      if (!s.isEmpty()) result+=" dla "+s;
       result+=".";
       return result;
     }
@@ -169,10 +173,6 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     QCString trFileList()
     { return "Lista plików"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    QCString trHeaderFiles()
-    { return "Pliki nagłówkowe"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     QCString trCompoundMembers()
     {
@@ -308,10 +308,6 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    QCString trHeaderFilesDescription()
-    { return "Tutaj znajdują się pliki nagłówkowe tworzące API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     QCString trExamplesDescription()
     { return "Tutaj znajduje się lista wszystkich przykładów:"; }
@@ -324,12 +320,6 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     QCString trModulesDescription()
     { return "Tutaj znajduje się lista wszystkich grup:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    QCString trNoDescriptionAvailable()
-    { return "Brak opisu"; }
-
     // index titles (the project name is prepended for these)
 
 
@@ -385,6 +375,10 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
       {
         return "Dokumentacja struktur danych";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Dokumentacja klas";
@@ -403,12 +397,6 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     QCString trExampleDocumentation()
     { return "Dokumentacja przykładów"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    QCString trPageDocumentation()
-    { return "Dokumentacja stron"; }
-
     /*! This is used in LaTeX as the title of the document */
     QCString trReferenceManual()
     { return "Podręcznik"; }
@@ -497,36 +485,24 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    QCString trGeneratedAt(const char *date,const char *projName)
+    QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Wygenerowano "+date;
-      if (projName) result+=(QCString)" dla "+projName;
-      result+=(QCString)" programem";
+      QCString result="Wygenerowano "+date;
+      if (!projName.isEmpty()) result+=" dla "+projName;
+      result+=" programem";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    QCString trClassDiagram(const char *clName)
+    QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Diagram dziedziczenia dla "+clName;
+      return "Diagram dziedziczenia dla "+clName;
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    QCString trForInternalUseOnly()
-    { return "Tylko do użytku wewnętrznego."; }
-
-    /*! this text is generated when the \\reimp command is used. */
-    QCString trReimplementedForInternalReasons()
-    { return "Reimplementowana z wewnętrzych przyczyn; nie dotyczy API."; }
-
     /*! this text is generated when the \\warning command is used. */
     QCString trWarning()
     { return "Ostrzeżenie"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    QCString trBugsAndLimitations()
-    { return "Błędy i ograniczenia"; }
-
     /*! this text is generated when the \\version command is used. */
     QCString trVersion()
     { return "Wersja"; }
@@ -591,7 +567,7 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    QCString trCompoundReference(const char *clName,
+    QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -608,12 +584,12 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
         case ClassDef::Exception:  result+=" wyjątku "; break;
         default: break;
       }
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
     /*! used as the title of the HTML page of a file */
-    QCString trFileReference(const char *fileName)
+    QCString trFileReference(const QCString &fileName)
     {
       QCString result="Dokumentacja pliku ";
       result+=fileName;
@@ -621,7 +597,7 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     }
 
     /*! used as the title of the HTML page of a namespace */
-    QCString trNamespaceReference(const char *namespaceName)
+    QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Dokumentacja przestrzeni nazw ";
       result+=namespaceName;
@@ -756,7 +732,7 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentacja dla te";
+      QCString result="Dokumentacja dla te";
       switch(compType)
       {
         case ClassDef::Class:      result+="j klasy"; break;
@@ -796,10 +772,6 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Źródła";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
       return "Definicja w linii @0 pliku @1.";
@@ -823,14 +795,14 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    QCString trCollaborationDiagram(const char *clName)
+    QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Diagram współpracy dla "+clName+":";
+      return "Diagram współpracy dla "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    QCString trInclDepGraph(const char *fName)
+    QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Wykres zależności załączania dla "+fName+":";
+      return "Wykres zależności załączania dla "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     QCString trConstructorDocumentation()
@@ -1110,14 +1082,9 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Pakiet "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Lista Pakietów";
+      return "Pakiet "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1129,11 +1096,6 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     {
       return "Pakiety";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Dokumentacja Pakietu";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1244,17 +1206,6 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
       return result;
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    {
-      QCString result((first_capital ? "Pol" : "pol"));
-      result+=(singular ? "e" : "a");
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1360,14 +1311,18 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funkcje pakietu";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Składowe pakietu";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statyczne funkcje pakietu";
     }
@@ -1485,19 +1440,11 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     virtual QCString trDirectories()
     { return "Katalogi"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    {
-      return "Ta struktura katalogów posortowana jest z grubsza, "
-             "choć nie całkowicie, alfabetycznie:";
-    }
 
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result="Dokumentacja katalogu "; result+=dirName; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1624,7 +1571,7 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -1641,11 +1588,11 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
         case ClassDef::Exception:  result+=" wyjątku "; break;
         default: break;
       }
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result="Dokumentacja modułu ";
       result+=namespaceName;
@@ -1696,7 +1643,7 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentacja dla te";
+      QCString result="Dokumentacja dla te";
       switch(compType)
       {
         case ClassDef::Class:      result+="go modułu"; break;
@@ -1744,7 +1691,7 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return "Relacja "+ QCString(name);
     }
@@ -1781,18 +1728,18 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Plik w "+name;
+      return "Plik w "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Zawiera plik w "+name;
+      return "Zawiera plik w "+name;
     }
 
     /** Compiles a date string.
@@ -1835,7 +1782,7 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Wykres zależności katalogu dla ")+name+":"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1862,11 +1809,11 @@ class TranslatorPolish : public TranslatorAdapter_1_8_2
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { QCString result="Dokumentacja wyliczenia "; result+=name; return result; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" dziedziczone z "+what; }
 
     /*! Header of the sections with inherited members specific for the
