@@ -15,15 +15,21 @@
  *       Fabio "FJTC" Jun Takada Chino <fjtc at brokenbits dot com dot br>
  *    Maintainer (until 04/28/2011):
  *       Rui Godinho Lopes <rui at ruilopes.com>
+ *    Collaborators:
+ *        Ulisses Guedes <uli1958 at hotmail dot com>
  *
  * Notes about this translation:
- *    Since I'm Brazilian, this translation may be odd or even incorect for
+ *    Since I'm Brazilian, this translation may be odd or even incorrect for
  *    Portuguese (from Portugal) speakers. If you find any errors, feel free
  *    to contact me.
  *
  * VERSION HISTORY
  * ---------------
  * History:
+ * 20211003:
+ *  - Updated to 1.9.3;
+ * 20200112:
+ * 	- Updated to 1.9.1;
  * 20190203:
  *	- Slice methods added;
  * 20180612:
@@ -59,7 +65,7 @@
 #define TRANSLATOR_PT_H
 
 
-class TranslatorPortuguese : public TranslatorAdapter_1_8_19
+class TranslatorPortuguese : public TranslatorAdapter_1_9_4
 {
   public:
 
@@ -98,6 +104,10 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     {
       return "pt";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x816 Portuguese(Portugal)";
+    }
 
     // --- Language translation methods -------------------
 
@@ -161,9 +171,9 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    QCString trGeneratedAutomatically(const char *s)
+    QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Gerado automaticamente por Doxygen";
-      if (s) result+=(QCString)" para "+s;
+      if (!s.isEmpty()) result+=" para "+s;
       result+=" a partir do código fonte.";
       return result;
     }
@@ -403,7 +413,20 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
      *  the documentation of all classes, structs and unions.
      */
     QCString trClassDocumentation()
-    { return "Documentação da classe"; }
+    {
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+      {
+        return "Documentação da estruturas de dados";
+      }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
+      else
+      {
+        return "Documentação da classe";
+      }
+    }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all files.
@@ -417,12 +440,6 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     QCString trExampleDocumentation()
     { return "Documentação do exemplo"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    QCString trPageDocumentation()
-    { return "Documentação da página"; }
-
     /*! This is used in LaTeX as the title of the document */
     QCString trReferenceManual()
     { return "Manual de referência"; }
@@ -511,24 +528,20 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    QCString trGeneratedAt(const char *date,const char *projName)
+    QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Gerado em "+date;
-      if (projName) result+=(QCString)" para "+projName;
-      result+=(QCString)" por";
+      QCString result="Gerado em "+date;
+      if (!projName.isEmpty()) result+=" para "+projName;
+      result+=" por";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    QCString trClassDiagram(const char *clName)
+    QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de heranças da classe "+clName;
+      return "Diagrama de heranças da classe "+clName;
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    QCString trForInternalUseOnly()
-    { return "Apenas para uso interno."; }
-
     /*! this text is generated when the \\warning command is used. */
     QCString trWarning()
     { return "Aviso"; }
@@ -599,7 +612,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -616,12 +629,12 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
         default: break;
       }
       if (isTemplate) result+="Template ";
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result= "Referência ao ficheiro ";
       result += fileName;
@@ -629,7 +642,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result= "Referência ao namespace ";
       result += namespaceName;
@@ -766,10 +779,11 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"A documentação para ";
+      bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
+      QCString result="A documentação para ";
       switch(compType)
       {
-        case ClassDef::Class:      result+="esta classe"; break;
+        case ClassDef::Class:      result+=vhdlOpt?"esta Unidade de Design":"esta classe"; break;
         case ClassDef::Struct:     result+="esta estrutura"; break;
         case ClassDef::Union:      result+="esta união"; break;
         case ClassDef::Interface:  result+="este interface"; break;
@@ -830,14 +844,14 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de colaboração para "+clName+":";
+      return "Diagrama de colaboração para "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Diagrama de dependências de inclusão para "+fName+":";
+      return "Diagrama de dependências de inclusão para "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1108,14 +1122,9 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Pacote "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Lista de pacotes";
+      return "Pacote "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1372,14 +1381,18 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funções do Pacote";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Membros do Pacote";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Funções Estáticas do Pacote";
     }
@@ -1491,16 +1504,10 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     virtual QCString trDirectories()
     { return "Diretórios"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Esta Hierarquia de Diretórios está parcialmente ordenada (ordem alfabética)"; }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     {
         QCString result = "Referência do diretório ";
      	result += dirName;
@@ -1628,11 +1635,11 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result = (QCString)"Referência ";
+      QCString result = "Referência ";
 
       if (isTemplate) result+="da Template ";
 
@@ -1652,7 +1659,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result = "Referência do Módulo ";
       result += namespaceName;
@@ -1703,7 +1710,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"A documentação para ";
+      QCString result="A documentação para ";
       switch(compType)
       {
         case ClassDef::Class:      result+="este modulo "; break;
@@ -1757,7 +1764,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
 
     /*! directory relation for \a name
      */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return "Relação " + QCString(name);
     }
@@ -1794,18 +1801,18 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Ficheiro em "+name;
+      return "Ficheiro em "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Inclui ficheiro em "+name;
+      return "Inclui ficheiro em "+name;
     }
 
     /** Compiles a date string.
@@ -1852,7 +1859,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Grafo de dependências do directório ")+name+":"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1883,14 +1890,14 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     {
       QCString result = "Referência da enumeração ";
       return result + name;
     }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" herdados de "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1971,7 +1978,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     { return "Grupos de Constantes"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result = "Referência do grupo de constantes ";
       result += namespaceName;
@@ -1979,7 +1986,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     }
 
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
       QCString result = "Referência do serviço ";
       result += sName;
@@ -1987,7 +1994,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     }
 
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
       QCString result = "Referência do Singleton ";
       result += sName;
@@ -1998,7 +2005,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"A documentação para este serviço "
+      QCString result="A documentação para este serviço "
                                 "foi gerada a partir ";
       if (single) {
         result+="do seguinte ficheiro:";
@@ -2012,7 +2019,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"A documentação para este singleton "
+      QCString result="A documentação para este singleton "
                                 "foi gerada a partir ";
       if (single) {
         result+="do seguinte ficheiro:";
@@ -2137,7 +2144,7 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
           return "Classe";
       }
     }
-    virtual QCString trCustomReference(const char *name)
+    virtual QCString trCustomReference(const QCString &name)
     { return "Referência de " + QCString(name); }
 
     /* Slice */
@@ -2237,9 +2244,9 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
     {
         return "Exceções";
     }
-    virtual QCString trCompoundReferenceSlice(const char *clName, ClassDef::CompoundType compType, bool isLocal)
+    virtual QCString trCompoundReferenceSlice(const QCString &clName, ClassDef::CompoundType compType, bool isLocal)
     {
-      QCString result=(QCString)"Referência ";
+      QCString result="Referência ";
       switch(compType)
       {
         case ClassDef::Class:      result+="da Classe "; break;
@@ -2272,7 +2279,61 @@ class TranslatorPortuguese : public TranslatorAdapter_1_8_19
         return "Dados Membros";
     }
 
+    //////////////////////////////////////////////////////////////////////////
+    // new since 1.8.19
+    //////////////////////////////////////////////////////////////////////////
 
+    /** VHDL design unit documentation */
+	virtual QCString trDesignUnitDocumentation()
+	{
+	    return "Documentação da Unidade de Projeto";
+    }
+
+
+	//////////////////////////////////////////////////////////////////////////
+	// new since 1.9.2
+	//////////////////////////////////////////////////////////////////////////
+	/** C++20 concept */
+	virtual QCString trConcept(bool first_capital, bool singular)
+	{
+	  QCString result((first_capital ? "Conceito" : "conceito"));
+	  if (!singular) result+="s";
+	  return result;
+	}
+	/*! used as the title of the HTML page of a C++20 concept page */
+	virtual QCString trConceptReference(const QCString &conceptName)
+	{
+	  QCString result= "Referência do Conceito ";
+	  result+=conceptName;
+	  return result;
+	}
+
+	/*! used as the title of page containing all the index of all concepts. */
+	virtual QCString trConceptList()
+	{ return "Lista de Conceitos"; }
+
+	/*! used as the title of chapter containing the index listing all concepts. */
+	virtual QCString trConceptIndex()
+	{ return "Índice de Conceitos"; }
+
+	/*! used as the title of chapter containing all information about concepts. */
+	virtual QCString trConceptDocumentation()
+	{ return "Documentação do Conceito"; }
+
+	/*! used as an introduction to the concept list */
+	virtual QCString trConceptListDescription(bool extractAll)
+	{
+	  QCString result="Esta é a lista de todos os conceitos ";
+	  if (!extractAll) result+="documentados ";
+	  result+="com suas respectivas descrições:";
+	  return result;
+	}
+
+	/*! used to introduce the definition of the C++20 concept */
+	virtual QCString trConceptDefinition()
+	{
+	  return "Definição de conceito";
+	}
 };
 
 #endif
