@@ -78,6 +78,10 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     {
       return "ro";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x418 Romanian";
+    }
 
     // --- Language translation methods -------------------
 
@@ -142,9 +146,9 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Generat automat de Doxygen";
-      if (s) result+=(QCString)" pentru "+s;
+      if (!s.isEmpty()) result+=" pentru "+s;
       result+=" din codul sursă.";
       return result;
     }
@@ -402,6 +406,10 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
       {
         return "Documentaţia Structurilor de Date";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Documentaţia Claselor";
@@ -421,12 +429,6 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     virtual QCString trExampleDocumentation()
     { return "Documentaţia Exemplelor"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Documentaţii înrudite"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Manual de utilizare"; }
@@ -516,24 +518,20 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Generat "+date;
-      if (projName) result+=(QCString)" pentru "+projName;
-      result+=(QCString)" de către";
+      QCString result="Generat "+date;
+      if (!projName.isEmpty()) result+=" pentru "+projName;
+      result+=" de către";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de relaţii pentru "+clName;
+      return "Diagrama de relaţii pentru "+clName;
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Doar pentru uz intern."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Atenţie"; }
@@ -603,7 +601,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -620,13 +618,13 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
         default: break;
       }
       if (isTemplate) result+=" (Template) ";
-      result+=(QCString)clName;
+      result+=clName;
 
       return result;
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result="Referinţă la fişierul ";
       result+=fileName;
@@ -634,7 +632,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Referinţă la Namespace-ul ";
       result+=namespaceName;
@@ -770,7 +768,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Documentaţia pentru această ";
+      QCString result="Documentaţia pentru această ";
       switch(compType)
       {
         case ClassDef::Class:      result+="clasă"; break;
@@ -833,14 +831,14 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de relaţii pentru "+clName+":";
+      return "Diagrama de relaţii pentru "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Graful dependenţelor prin incluziune pentru "+fName+":";
+      return "Graful dependenţelor prin incluziune pentru "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1115,14 +1113,9 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Pachet "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Lista Pachetelor";
+      return "Pachet "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1379,14 +1372,18 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funcţii în pachet";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Membrii în pachet";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Funcţii statice în pachet";
     }
@@ -1498,18 +1495,10 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
      virtual QCString trDirectories()
      { return "Directoare"; }
 
-     /*! This returns a sentences that introduces the directory hierarchy.
-      *  and the fact that it is sorted alphabetically per level
-      */
-     virtual QCString trDirDescription()
-     { return "Această ierarhie de directoare este sortată în general, "
-              "dar nu complet, în ordine alfabetică:";
-     }
-
      /*! This returns the title of a directory page. The name of the
       *  directory is passed via \a dirName.
       */
-     virtual QCString trDirReference(const char *dirName)
+     virtual QCString trDirReference(const QCString &dirName)
      {
        QCString  result="Director-referinţă "; result+=dirName;
        return result;
@@ -1639,7 +1628,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -1656,11 +1645,11 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
         default: break;
       }
       if (isTemplate) result+="(Template) ";
-	  result+=(QCString)clName;
+	  result+=clName;
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result="Referinţă la Modulul ";
 	  result += namespaceName;
@@ -1712,7 +1701,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Documentaţia ";
+      QCString result="Documentaţia ";
       switch(compType)
       {
         case ClassDef::Class:      result+="modulului"; break;
@@ -1762,7 +1751,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" Relație";
     }
@@ -1799,18 +1788,18 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Fișierul din "+name;
+      return "Fișierul din "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Include fișierul din "+name;
+      return "Include fișierul din "+name;
     }
 
     /** Compiles a date string.
@@ -1853,7 +1842,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Grafic de dependență a directoarelor pentru ")+name+":"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1883,11 +1872,11 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString(name)+" Referință Enum"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" moștenit(e) din "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1968,23 +1957,23 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     { return "Grupuri Constante"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" Referință Grup Constant";
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Referință Serviciu";
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Referință Singleton";
       return result;
     }
@@ -1992,7 +1981,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Documentația pentru acest serviciu "
+      QCString result="Documentația pentru acest serviciu "
                                 "a fost generată din ";
       if (single)
         result += "următorul fișier:";
@@ -2004,7 +1993,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_8_15
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Documentația pentru acest singleton "
+      QCString result="Documentația pentru acest singleton "
                                 "a fost generată din ";
       if (single)
         result += "următorul fișier:";
