@@ -62,6 +62,10 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     {
       return "sr-Latn";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x81A Serbian (Serbia, Latin)";
+    }
 
     // --- Language translation methods -------------------
 
@@ -128,9 +132,9 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Napravljeno automatski korišćenjem alata Doxygen";
-      if( s ) result+=(QCString)" za projekat " + s;
+      if (!s.isEmpty()) result+=" za projekat " + s;
       result+=" od izvornog koda.";
       return result;
     }
@@ -235,6 +239,10 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       {
         return "Spisak struktura sa kratkim opisima:";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Spisak klasa sa kratkim opisima:";
+      }
       else
       {
         return "Spisak klasa, struktura, unija i interfejsa sa kratkim opisima:";
@@ -371,6 +379,10 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       {
         return "Dokumentacija stuktura/unija";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Dokumentacija klasa";
@@ -389,12 +401,6 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     virtual QCString trExampleDocumentation()
     { return "Dokumentacija primera"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Dokumentacija stranice"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Priručnik"; }
@@ -483,24 +489,20 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"[" + date + "] Napravljeno automatski ";
-      if ( projName ) result+=(QCString)" za projekat " + projName;
-	  result+=(QCString)" upotrebom ";
+      QCString result="[" + date + "] Napravljeno automatski ";
+      if (!projName.isEmpty()) result+=" za projekat " + projName;
+	  result+=" upotrebom ";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
       return QCString("Dijagram nasleđivanja za klasu ") + clName + ":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Samo za unutrašnju upotrebu."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Upozorenje"; }
@@ -571,7 +573,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -593,7 +595,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result = "Opis datoteke ";
       result += fileName;
@@ -601,7 +603,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Opis prostora imena ";
       result += namespaceName;
@@ -735,7 +737,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentacija ";
+      QCString result="Dokumentacija ";
       switch(compType)
       {
         case ClassDef::Class:      result+="ove klase"; break;
@@ -798,14 +800,14 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Klasni dijagram za "+clName+":";
+      return "Klasni dijagram za "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Graf zavisnosti datoteka za "+fName+":";
+      return "Graf zavisnosti datoteka za "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1083,14 +1085,9 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paket "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Spisak paketa";
+      return "Paket "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1348,14 +1345,18 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funkcije u paketu";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Članovi u paketu";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statičke funkcije u paketu";  // Zajednicke funkcije u paketu
     }
@@ -1467,16 +1468,10 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     virtual QCString trDirectories()
     { return "Direktorijumi"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Hijerarhija direktorijuma uređena približno po abecedi:"; }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+="Opis direktorijuma"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1604,11 +1599,11 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Modul"; break;
@@ -1625,7 +1620,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" - sažet pregled modula";
@@ -1676,7 +1671,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentacija za ovaj ";
+      QCString result="Dokumentacija za ovaj ";
       switch(compType)
       {
         case ClassDef::Class:      result+="modul"; break;
@@ -1719,59 +1714,11 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       return "Ograničenja tipova";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// following methods have no corresponding entry in translator_en.h
-//////////////////////////////////////////////////////////////////////////
-
-//      /*! This is put above each page as a link to the list of all verbatim headers */
-//     virtual QCString trHeaderFiles()
-//     { return "Zaglavlja"; }
-//
-//     /*! This is an introduction to the page with the list of all header files. */
-//     virtual QCString trHeaderFilesDescription()
-//     { return "Zaglavlja koje izgraduju API:"; }
-//
-//     /*! This sentences is used in the annotated class/file lists if no brief
-//      * description is given.
-//      */
-//     virtual QCString trNoDescriptionAvailable()
-//     { return "Opis nije dostupan"; }
-//
-//     /*! this text is generated when the \\reimp command is used. */
-//     virtual QCString trReimplementedForInternalReasons()
-//     { return decode("Preuradeno zbog unutrasnjih razloga; Nema uticaja na API." ); }
-//
-//     /*! this text is generated when the \\bug command is used. */
-//     virtual QCString trBugsAndLimitations()
-//     { return "Greske i ogranicenja"; }
-//
-//     virtual QCString trSources()
-//     {
-//       return decode("Izvorne datoteke" );
-//     }
-//
-//     /*! Used for Java interfaces in the summary section of Java packages */
-//     virtual QCString trInterfaces()
-//     {
-//       return "Interfejsi";  //!< Radna okruzenja. Ali to je dve reci.
-//     }
-//
-//     /*! Used as a chapter title for Latex & RTF output */
-//     virtual QCString trPackageDocumentation()
-//     {
-//       return "Dokumentacija paketa";
-//     }
-//
-//     /*! This is used for translation of the word that will possibly
-//      *  be followed by a single name or by a list of names
-//      *  of the category.
-//      */
-//     virtual QCString trField(bool first_capital, bool singular)
-//     {
-//       QCString result((first_capital ? "Polj" : "polj"));
-//       result+= (singular ? "e" : "a");
-//       return result;
-//     }
+    /*! Used for Java interfaces in the summary section of Java packages */
+    virtual QCString trInterfaces()
+    {
+      return "Interfejsi";  //!< Radna okruzenja. Ali to je dve reci.
+    }
 
 };
 
