@@ -21,8 +21,7 @@
  * vhdl documents
  */
 
-#include <qdict.h>
-#include <qcstring.h>
+#include "qcstring.h"
 #include "layout.h"
 #include "arguments.h"
 #include "entry.h"
@@ -32,19 +31,17 @@ class ClassDef;
 class MemberList;
 class MemberDef;
 class MemberDefMutable;
-class FTextStream;
 class OutputList;
 class Definition;
 class GroupDef;
 class FileDef;
 class NamespaceDef;
+class TextStream;
 struct Argument;
 
-
-
 struct VhdlConfNode
 {
-  VhdlConfNode(const char*  a,const char*  b,const char* config,const char* cs,bool leaf)
+  VhdlConfNode(const QCString &a,const QCString &b,const QCString &config,const QCString &cs,bool leaf)
   {
     arch=a;              // architecture  e.g. for iobuffer
     arch=arch.lower();
@@ -79,6 +76,17 @@ class VhdlDocGen
       ARCHITECTURECLASS,   // Overlays: Private
       PACKAGECLASS         // Overlays: Package
     };
+    static VhdlClasses convert(Protection prot)
+    {
+      switch (prot)
+      {
+        case Public:    return ENTITYCLASS;
+        case Protected: return PACKBODYCLASS;
+        case Private:   return ARCHITECTURECLASS;
+        case Package:   return PACKAGECLASS;
+      }
+      return ENTITYCLASS;
+    }
 
     enum VhdlKeyWords
     {
@@ -119,10 +127,10 @@ class VhdlDocGen
 
     static bool isSubClass(ClassDef* cd,ClassDef *scd, bool followInstances,int level);
 
-    static QCString getIndexWord(const char* ,int index);
+    static QCString getIndexWord(const QCString &,int index);
     static bool     deleteCharRev(QCString &s,char c);
     static void     deleteAllChars(QCString &s,char c);
-    static void     parseFuncProto(const char* text,
+    static void     parseFuncProto(const QCString &text,
                                    QCString& name,
                                    QCString& ret,
                                    bool doc=false);
@@ -133,19 +141,19 @@ class VhdlDocGen
     static const char* findKeyWord(const QCString& word);
 
     static ClassDef* getPackageName(const QCString& name);
-    static MemberDef* findMember(const QCString& className,
+    static const MemberDef* findMember(const QCString& className,
                                  const QCString& memName);
     static void findAllPackages(ClassDef*);
-    static MemberDef* findMemberDef(ClassDef* cd,
+    static const MemberDef* findMemberDef(ClassDef* cd,
                                 const QCString& key,
                                 MemberListType type);
-    static ClassDef *getClass(const char *name);
-    static MemberDef* findFunction(const QCString& name,
+    static ClassDef *getClass(const QCString &name);
+    static const MemberDef* findFunction(const QCString& name,
                                    const QCString& package);
     static QCString getClassTitle(const ClassDef*);
     static void writeInlineClassLink(const ClassDef*,
                                      OutputList &ol);
-    static void writeTagFile(MemberDefMutable *mdef,FTextStream &tagFile);
+    static void writeTagFile(MemberDefMutable *mdef,TextStream &tagFile);
 
     static bool isConstraint(const MemberDef *mdef);
     static bool isConfig(const MemberDef *mdef);
@@ -197,11 +205,11 @@ class VhdlDocGen
 
     static void writePlainVHDLDeclarations(const MemberList* ml,OutputList &ol,
         const ClassDef *cd,const NamespaceDef *nd,const FileDef *fd,const GroupDef *gd,
-        int specifier);
+        uint64_t specifier);
 
     static void writeVHDLDeclarations(const MemberList* ml,OutputList &ol,
         const ClassDef *cd,const NamespaceDef *nd,const FileDef *fd,const GroupDef *gd,
-        const char *title,const char *subtitle,bool showEnumValues,int type);
+        const QCString &title,const QCString &subtitle,bool showEnumValues,int type);
 
     static bool writeClassType(const ClassDef *,OutputList &ol ,QCString & cname);
 
@@ -210,13 +218,12 @@ class VhdlDocGen
     static QCString getRecordNumber();
 
     static QCString getClassName(const ClassDef*);
-    static bool isNumber(const QCString& s);
+    static bool isNumber(const std::string& s);
     static QCString getProtectionName(int prot);
 
-    static void parseUCF(const char*  input,Entry* entity,QCString f,bool vendor);
+    static void parseUCF(const char*  input,Entry* entity,const QCString &f,bool vendor);
 
     static const ClassDef*  findArchitecture(const ClassDef *cd);
-    //static const ClassDef*  findArchitecture(QCString identifier, QCString entity_name);
 
     static void correctMemberProperties(MemberDefMutable *md);
 
@@ -225,14 +232,14 @@ class VhdlDocGen
     static QCString  parseForConfig(QCString & entity,QCString & arch);
     static QCString  parseForBinding(QCString & entity,QCString & arch);
     static void addBaseClass(ClassDef* cd,ClassDef *ent);
-    static ClassDef* findVhdlClass(const char *className );
+    static ClassDef* findVhdlClass(const QCString &className );
 
     static void writeOverview(OutputList &ol);
     static void writeOverview();
 
  // flowcharts
     static void createFlowChart(const MemberDef*);
-    //static void addFlowImage(const FTextStream &,const QCString &);
+    //static void addFlowImage(const TextStream &,const QCString &);
 
     static void setFlowMember( const MemberDef *flowMember);
     static const MemberDef *getFlowMember();
@@ -248,7 +255,7 @@ class VhdlDocGen
   static void resetCodeVhdlParserState();
 
   private:
-    static void findAllArchitectures(QList<QCString>& ql,const ClassDef *cd);
+    static void findAllArchitectures(std::vector<QCString>& ql,const ClassDef *cd);
     static bool compareArgList(const ArgumentList &,const ArgumentList &);
     static void writeVhdlLink(const ClassDef* cdd ,OutputList& ol,QCString& type,QCString& name,QCString& beh);
     static void writeStringLink(const MemberDef *mdef,QCString mem,OutputList& ol);
@@ -292,45 +299,42 @@ class FlowChart
 
     //---------- create svg -------------------------------------------------------------
     static void createSVG();
-    static void startDot(FTextStream &t);
-    static void endDot(FTextStream &t);
-    static void codify(FTextStream &t,const char *str);
-    static void writeShape(FTextStream &t,const FlowChart* fl);
-    static void writeEdge(FTextStream &t,int fl_from,int fl_to,int i,bool bFrom=FALSE,bool bTo=FALSE);
-    static void writeEdge(FTextStream &t,const FlowChart* fl_from,const FlowChart* fl_to,int i);
-    static void writeFlowLinks(FTextStream &t);
+    static void startDot(TextStream &t);
+    static void endDot(TextStream &t);
+    static void codify(TextStream &t,const QCString &str);
+    static void writeShape(TextStream &t,const FlowChart &fl);
+    static void writeEdge(TextStream &t,int fl_from,int fl_to,int i,bool bFrom=FALSE,bool bTo=FALSE);
+    static void writeEdge(TextStream &t,const FlowChart &fl_from,const FlowChart &fl_to,int i);
+    static void writeFlowLinks(TextStream &t);
 
     static QCString getNodeName(int n);
     static void colTextNodes();
 
-    static int getNextTextLink(const FlowChart* fl,uint index);
-    static int getNextIfLink(const FlowChart*,uint);
-    static int getNextNode(int,int);
-    static int findNode(int index,int stamp,int type);
-    static int findNode(int index,int type);
-    static int findNextLoop(int j,int stamp);
-    static int findPrevLoop(int j,int stamp,bool endif=FALSE);
-    static int findLabel(int j,QCString &);
+    static size_t getNextIfLink(const FlowChart&,size_t);
+    static size_t getNextNode(size_t index,int stamp);
+    static size_t findNode(size_t index,int stamp,int type);
+    static size_t findNode(size_t index,int type);
+    static size_t findNextLoop(size_t j,int stamp);
+    static size_t findPrevLoop(size_t j,int stamp,bool endif=FALSE);
+    static size_t findLabel(size_t j,const QCString &);
     static void delFlowList();
     static const char* getNodeType(int c);
 
-    static void addFlowChart(int type,const char* text,const char* exp,const char * label=0);
+    static void addFlowChart(int type,const QCString &text,const QCString &exp,const QCString &label=QCString());
     static void moveToPrevLevel();
     static int getTimeStamp();
     static void writeFlowChart();
     static void alignFuncProc(QCString & q,const ArgumentList &al,bool isFunc);
     static QCString convertNameToFileName();
-    static void printNode(const FlowChart* n);
+    static void printNode(const FlowChart& n);
     static void printFlowTree();
-    static void buildCommentNodes(FTextStream &t);
-    static void alignCommentNode(FTextStream &t,QCString com);
+    static void buildCommentNodes(TextStream &t);
+    static void alignCommentNode(TextStream &t,QCString com);
 
     static void  printUmlTree();
-    static QCString printPlantUmlNode(const FlowChart *flo,bool,bool);
+    static QCString printPlantUmlNode(const FlowChart &flo,bool,bool);
 
-    static QList<FlowChart> flowList;
-
-    FlowChart(int typ,const char*  t,const char* ex,const char* label=0);
+    FlowChart(int typ,const QCString &t,const QCString &ex,const QCString &label=QCString());
     ~FlowChart();
 
 private:
@@ -345,4 +349,6 @@ private:
     QCString exp;
 };
 
+extern std::vector<FlowChart> flowList;
+
 #endif
