@@ -1,7 +1,7 @@
 #!/usr/bin/python
-# python script to generate configoptions.cpp and config.doc from config.xml
+# python script to adjust generated VhdlParser.cc
 #
-# Copyright (C) 1997-2020 by Dimitri van Heesch.
+# Copyright (C) 1997-2021 by Dimitri van Heesch.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation under the terms of the GNU General Public License is hereby
@@ -18,7 +18,7 @@ def main():
     inputFile = open(sys.argv[1], 'r')
     outputFile = open(sys.argv[2], 'w')
     for line in inputFile:
-        outputFile.write(line.replace("assert(false);","assert(false);return \"\";"))
+        outputFile.write(line.replace("assert(false);","assert(false);return QCString();"))
 
 if __name__ == '__main__':
     main()
